!Subroutine to determine the number of atoms around a lattice site
!Useful during deposition routines and diffusion
!Checks all boundary conditions, which were getting tedious to do in-line
!Returns the coordination, and if its value is 1, also the position of the atom
!Starting with 1 at the lower left corner and increasing clockwise around the atom with 6 total spots
!
!We need to change the function of this routine.
!Needs to associate coordination number with the lattice site.
!Needs to cite location of the neighbors
!
!Variables
!cooridnation, boundaryConditionModifier, evenIndex, oddIndex, xIndex, yIndex, evenness, substrateWidth
!grid(;,:)
!
!Modules & subroutines
!globalVariables
module coordinationHelpers
	use globalVariables
	use indexConversion
	public :: coordinationCalculation, singleNeighborFinder
	
	contains
	!coordinationCalculation is not side effect free currently.  It should be soon however
	function coordinationCalculation(xIndex, yIndex) result (coordination)
	
		integer, intent(in) :: xIndex, yIndex
		integer:: coordination, oddModifierLocal
		boundaryConditionModifier = 0
		!evenIndex & oddIndex are modifiers to eliminate if statements in the momentum deposit program
		!Don't we need to use these in the boundary condition situations as well?  I think that's what boudnary condition oen is
		!Need to convert this to a more standard format
		coordination = 0
		
		!Determine the evenness of the lattice site
		if (mod(yIndex,2) > 0)	then
			oddModifierLocal = 1
		else
			oddModifierLocal = 0
		endif
			
!		!print *, 'xIndex', xIndex, 'yIndex', yIndex
		if (xIndex > substrateWidth .or. xIndex < 0) then
			!print *, 'Atom outside of simulation region!', xIndex
		endif

		!Calculate coordination number for bulk lattice sites	
		coordination = grid(boundaryConditionChecker(xIndex -oddModifierLocal), yIndex -1)%occupationNumber + &
		grid(boundaryConditionChecker(xIndex-1),yIndex)%occupationNumber + &
		grid(boundaryConditionChecker(xIndex-oddModifierLocal),yIndex+1)%occupationNumber + &
		grid(boundaryConditionChecker(xIndex +1 -oddModifierLocal), yIndex+1)%occupationNumber + &
		grid(boundaryConditionChecker(xIndex +1), yIndex)%occupationNumber + &
		grid(boundaryConditionChecker(xIndex +1 -oddModifierLocal), yIndex -1)%occupationNumber
		
		end function coordinationCalculation
		
	function singleNeighborFinder(xIndexLocal,yIndexLocal) result(singleNeighborLocation)
	!Point to where the single atom is located around the lattice site, for all BC's

			integer, intent(in) :: xIndexLocal, yIndexLocal
			integer :: singleNeighborLocation, evenness
			!Determine the evenness of the lattice site
			if (mod(yIndexLocal,2) /= 0)	then
				evenness = 0
			else
				evenness = 1
			endif
			
			if(grid(boundaryConditionChecker(xIndexLocal -1 + evenness), yIndexLocal -1)%occupationNumber ==1) then
				singleNeighborLocation = 1
			elseif (grid(boundaryConditionChecker(xIndexLocal - 1), yIndexLocal)%occupationNumber == 1) then
						
				singleNeighborLocation = 2
			elseif (grid(boundaryConditionChecker(xIndexLocal -1 +evenness), yIndexLocal + 1)%occupationNumber == 1) then
				
				singleNeighborLocation = 3
			elseif (grid(boundaryConditionChecker(xIndexLocal + evenness), yIndexLocal + 1)%occupationNumber == 1) then
				
				singleNeighborLocation = 4
			elseif (grid(boundaryConditionChecker(xIndexLocal +1), yIndexLocal)%occupationNumber == 1) then
				
				singleNeighborLocation = 5
			elseif (grid(boundaryConditionChecker(xIndexLocal + evenness), yIndexLocal -1)%occupationNumber == 1) then
				
				singleNeighborLocation = 6
			else
				!print *, 'Neighbor locator error 1'
			endif
			!print *, 'singleNeighborLocation', singleNeighborLocation
		end function singleNeighborFinder				
	
end module coordinationHelpers