!Reads the next incident vapor atom, and deposits it onto the substrate
!If an atom lands on an unstable lattice site, it will relax until a stable location is reached
!If the atom goes outside the width of the simulated area, loop it around to the other side
!Variables used in subroutine, that must be accounted for:
!i, newAtom struct, depositTime, deposited, xIndex, yIndex, gridMaxHeight, deltaYGrid
!Subroutines or modules called:
! globalVariables, xVaporCalculator, coordinationHelpers, indexConversion, momentumDeposit
!trajectoryHelpers
!
subroutine deposit()

	use globalVariables
	use xVaporCalc
	use coordinationHelpers
	use indexConversion
	use momentumDepositTool
	use trajectoryHelpers
	!Assign values for each atom
	integer :: i, xSites, j, oddModifier, xIndexOldInt, yIndexOld, xTemp, depositTrue, xNext, yNext, xInitial
	real :: xDelta, realXIndex, xMid, yTemp, xIndexOldReal
	real, dimension(1,2) :: xIndexes
	integer, dimension(2,11) :: movieCoordinates

	!Assign initial values to the current vapor atom
	newAtom%xVapor = depositionFlux(atomCount,1)
	newAtom%thetaVapor = depositionFlux(atomCount, 2)
	newAtom%yVapor = gridMaxHeight + 1
	newAtom%deltaYVapor = deltaYGrid
	
	!Check whether the initial row is odd or even
	if (mod(newAtom%yVapor,2) /= 0) then
		oddModifier = 1
	else
		oddModifier = 0
	endif
	
	!Find the integer position of the new atom on the grid and then calculate the trajectory
	xInitial = boundaryConditionChecker(NINT(newAtom%xVapor) - 1 + oddModifier)
	call trajectoryFinder(xInitial, newAtom%yVapor, NINT(newAtom%thetaVapor))
	
	!Update the movieGrid
	if (movieIndex <= movieIndexMax) then
		movieCoordinates = movieCoordinateFinder(boundaryConditionChecker(NINT(newAtom%xVapor)-1 +oddModifier), newAtom%yVapor)
		movieGrid(movieCoordinates(1,1),movieCoordinates(2,1), movieIndex) = 2
!		movieIndex = movieIndex + 1
		!if (movieIndex <= movieIndexMax) then
		!movieGrid(movieCoordinates(1,1), movieCoordinates(2,1), movieIndex) = 0
		!endif
	endif
!	!print *, newAtom%xVapor, newAtom%thetaVapor, gridMaxHeight
	!Change to 1 once atom is deposited
	depositTrue = 0
	depositTime = 0.0
	i = 1
	
	do i = 1, atomPath(1,3)
		
		coordination = 0
		if (atomPath(i,1) > substrateWidth) then
			!print *, 'Screwyness', atomPath(i,1), xInitial, i, atomPath(i-1,1)
		endif
		coordination = coordinationCalculation(atomPath(i, 1), atomPath(i,2))
		
		!Update the movieGrid
		movieIndex = movieIndex +1
		if (movieIndex <= movieIndexMax) then
			movieCoordinates = movieCoordinateFinder(atomPath(i, 1), atomPath(i,2))
			movieGrid(movieCoordinates(1,1),movieCoordinates(2,1), movieIndex) = 2
	!		movieIndex = movieIndex + 1
			!if (movieIndex <= movieIndexMax) then
			!movieGrid(movieCoordinates(1,1), movieCoordinates(2,1), movieIndex) = 0
			!endif
		endif
		
		if (coordination > 0) then
			depositTrue = momentumDeposit(atomPath(i,1), atomPath(i,2), atomPath(i+1,1), atomPath(i+1,2))
			!!print *, 'movieIndex', movieIndex
			if(depositTrue == 1) then
				exit
			endif
		endif
	enddo

end subroutine deposit