!Subroutine to update the jumpTree when an atom is deposited.  Need to zero the values out for covered atoms
!and calculate values for the newly deposited atom
!
!I don't think we need a matrix for the leafIndex variable, since we call siteJumpInfo everytime
!We need to account for boundary conditions in this subroutine
subroutine depositionUpdate(depositedXIndex, depositedYIndex)

	use indexConversion
	use globalVariables

	integer :: oddModifier, xIndexLocal, i
	integer, intent(in) :: depositedXIndex, depositedYIndex
	integer, dimension(11) :: leafIndex, leafEnergyIndex
	integer, dimension(2, 11) :: movieCoordinates
!	integer, dimension(6,6) :: treeIntersection = 0 sdf
	
	!Determine the evenness of the lattice site
	if (mod(depositedYIndex,2) > 0)	then
		oddModifier = 1
	else
		oddModifier = 0
	endif
	
	xIndexLocal = boundaryConditionChecker(depositedXIndex)
	
	!Advance the movie index
	if(movieIndex < movieIndexMax) then
		movieIndex = movieIndex +1
		!Update the movie grid
		movieCoordinates = movieCoordinateFinder(xIndexLocal, depositedYIndex)
!		print *, movieCoordinates, 'DepositionUpdate'
!		print*, 'xIndex', xIndexLocal, 'yIndex', depositedYIndex
		movieGrid(movieCoordinates(1,1),movieCoordinates(2,1), movieIndex) = 2
		movieGrid(movieCoordinates(1,2:5),movieCoordinates(2,2:5), movieIndex) = 5
		movieGrid(movieCoordinates(1,6:9),movieCoordinates(2,6:9), movieIndex) = 4
		movieGrid(movieCoordinates(1,10:11),movieCoordinates(2,10:11), movieIndex) = 5
	endif
	
	!update jump energies.
	!Set energies to zero if atom is now totally surrounded
	!Although the atom cannot move to the two spots below/above it, it can influence its jump ability
	!by changing its coordination number
	!We don't need to call the coordinationCalculation or anything, we can just do siteJumpInfo for all cases
	
	!Udpdate the deposited location
	leafIndex(11) = gridToJump(xIndexLocal, depositedYIndex)
	leafEnergyIndex(11) = jumpToEnergy(leafIndex(11))
	

	
	do i = 0, 1
		!Check the above and below sites, will modify their coordination and jump values
!		print *, 'oddModifier', oddModifier
		leafIndex(i+1) = gridToJump(boundaryConditionChecker(xIndexLocal +i -oddModifier), depositedYIndex -1)
		leafEnergyIndex(i+1) = jumpToEnergy(leafIndex(i+1))
!		call siteJumpInfo(leafIndex(i+1))
		leafIndex(i+3) = gridToJump(boundaryConditionChecker(xIndexLocal +i -oddModifier), depositedYIndex +1)
		leafEnergyIndex(i+3) = jumpToEnergy(leafIndex(i+3))
!		call siteJumpInfo(leafIndex(i+3))
	enddo
	
	!Modify the Schowebel jumps above and below
	leafIndex(7) = gridToJump(boundaryConditionChecker(xIndexLocal -1 -oddModifier), depositedYIndex -1)
	leafEnergyIndex(7) = jumpToEnergy(leafIndex(7))
!	call siteJumpInfo(leafIndex(7))
	leafIndex(8) = gridToJump(boundaryConditionChecker(xIndexLocal +2 -oddModifier), depositedYIndex -1)
	leafEnergyIndex(8) = jumpToEnergy(leafIndex(8))
!	call siteJumpInfo(leafIndex(8))
	leafIndex(9) = gridToJump(boundaryConditionChecker(xIndexLocal -1 -oddModifier), depositedYIndex +1)
	leafEnergyIndex(9) = jumpToEnergy(leafIndex(9))
!	call siteJumpInfo(leafIndex(9))
	leafIndex(10) = gridToJump(boundaryConditionChecker(xIndexLocal +2 -oddModifier), depositedYIndex +1)
	leafEnergyIndex(10) = jumpToEnergy(leafIndex(10))
!	call siteJumpInfo(leafIndex(10))
 
	!Update the sites to the immediate left and right
	leafIndex(5) = gridToJump(boundaryConditionChecker(xIndexLocal -1), depositedYIndex)
	leafEnergyIndex(5) = jumpToEnergy(leafIndex(5))
!	call siteJumpInfo(leafIndex(5))
	leafIndex(6) = gridToJump(boundaryConditionChecker(xIndexLocal +1), depositedYIndex)
	leafEnergyIndex(6) = jumpToEnergy(leafIndex(6))
!	call siteJumpInfo(leafIndex(6))
	
	!Go through all the leafIndices and update their jump parameters
	do i = 1, 11
		!print *, 'Updating siteJumpInfo'
		!Check for the odd/even index of the lattice site
		if (i /= 5 .and. i /= 6 .and. i /=11)	then
			if (oddModifier == 1)	then
				call siteJumpInfo(leafIndex(i), leafEnergyIndex(i), 0)
			else
				call siteJumpInfo(leafIndex(i), leafEnergyIndex(i), 1)
			endif
		else
			call siteJumpInfo(leafIndex(i), leafEnergyIndex(i), oddModifier)
		endif
!		print *, 'New site energy', jumpTree(leafIndex(i))
		if (jumpTree(leafIndex(i)) > 1.0)	then
!			print *, 'Coordinates', jumpToGrid(leafIndex(i))
		endif
	enddo
	
end subroutine depositionUpdate