!Jump probability calculator
!Returns an array of the jump probabilities for given conditions
!Will be constant during each simulation, but vary with temperature
!This is also a good location to set the deposition time interval
!
!Variables
!vibrationRate, kB, i, j, probabilities(:,:), barrier(:,:), substrateTemperature, depositTimeInterval, deltaXGrid
!substrateWidth, depositionRate
!
!Modules & subroutines
!globalVariables
subroutine diffusionInitialize()

	use globalVariables
	
	!Set vibrationRate and Boltzmann's constant (kB) both are invarient
	real, parameter :: vibrationRate = 5.0e12
	real, parameter :: kB = 8.6173324e-5
	
	!Calculate the probabilities for each jumpEnergy
	!Energies are sorted in ascending order, which makes the probabilities sorted in descending
	probabilities(1) = vibrationRate*EXP(-0.017/ (kB * substrateTemperature))
	probabilities(2) = vibrationRate*EXP(-0.335/ (kB * substrateTemperature))
	probabilities(3) = vibrationRate*EXP(-0.408/ (kB * substrateTemperature))
	probabilities(4) = vibrationRate*EXP(-0.447/ (kB * substrateTemperature))
	probabilities(5) = vibrationRate*EXP(-0.472/ (kB * substrateTemperature))
	probabilities(6) = vibrationRate*EXP(-0.543/ (kB * substrateTemperature))
	probabilities(7) = vibrationRate*EXP(-0.706/ (kB * substrateTemperature))
	probabilities(8) = vibrationRate*EXP(-0.739/ (kB * substrateTemperature))
	probabilities(9) = vibrationRate*EXP(-0.819/ (kB * substrateTemperature))
	probabilities(10) = vibrationRate*EXP(-0.821/ (kB * substrateTemperature))
	probabilities(11) = vibrationRate*EXP(-0.822/ (kB * substrateTemperature))
	probabilities(12) = vibrationRate*EXP(-0.848/ (kB * substrateTemperature))
	probabilities(13) = vibrationRate*EXP(-0.92/ (kB * substrateTemperature))
	probabilities(14) = vibrationRate*EXP(-1.089/ (kB * substrateTemperature))
	probabilities(15) = vibrationRate*EXP(-1.09/ (kB * substrateTemperature))
	probabilities(16) = vibrationRate*EXP(-1.101/ (kB * substrateTemperature))
	probabilities(17) = vibrationRate*EXP(-1.121/ (kB * substrateTemperature))
	probabilities(18) = vibrationRate*EXP(-1.142/ (kB * substrateTemperature))
	probabilities(19) = vibrationRate*EXP(-1.204/ (kB * substrateTemperature))
	probabilities(20) = 0.0
	
	!Calculate interval between atom arrivals
	!from the formula dt = Sqrt(3) *a/(2*n*R)
	!Units: deltaXGrid - m, depositionRate - m/s, substrateWidth - none (its # of atoms)
	depositTimeInterval = SQRT(3.0) * deltaXGrid /(2 * substrateWidth * depositionRate)
!	print *, deltaXGrid, substrateWidth, depositionRate
!	print *, 'depositTimeInterval', depositTimeInterval
!	print *, 'probabilities', probabilities

end subroutine diffusionInitialize