!Subroutine to create an initial grid for simulation.  Using a hexagonal-packed lattice.
!All positions initially vacant or generates grid from restart information.
!Variables:
!grid(:,:), substrateWidth, filmHeightMax, numberOfInitialLayers, deltaYGrid, deltaXGrid, gridMaxHeight
!Allocates:
!grid, movieGrid
!Modules & subroutines
!globalVariables

subroutine gridInitialize()

	use globalVariables	
	integer :: i,j, moundInterval, moundCenter, oddModifier, oppositeMod
	
!	Create array of gridIndex objects using the width and height needed
	allocate(grid(substrateWidth, filmHeightMax+10))
	
	!Create array for depositionAtom path.  Maximum filmHeight * 29, faster than allocating each time
	allocate(atomPath(filmHeightMax*29,3))
	
	!Allocate movieGrid if needed.  This was wasting space the size of one iteration earlier.
	!Need to make sure all movie features are optional.
	if (movieIndexMax > 0) then
		allocate(movieGrid(substrateWidth, filmHeightMax, movieIndexMax))
	endif
	
!	Set occupationNumber to vacant = 0, except for the first rows as specified by numberOfInitialLayers
	grid(1:substrateWidth, numberOfInitialLayers + 1:filmHeightMax)%occupationNumber = 0
	grid(1:substrateWidth, 1:numberOfInitialLayers)%occupationNumber = 1

!	Set the initial movie color codes of the lattice sites. (We'll set all the steps as this, as they should be similar	
	if (movieIndexMax > 0) then
		movieGrid(1:substrateWidth, 1:numberOfInitialLayers, :) = 1
		movieGrid(1:substrateWidth, numberOfInitialLayers + 1:filmHeightMax, :) = 0
	endif	
	
	if(MOD(numberOfInitialLayers,2) /= 0) then
		oddModifier = 1
		oppositeMod = 0
	else
		oddModifier = 0
		oppositeMod = 1
	endif
	
	!Create mounds on the initial computational grid
	!For simplicity, lets have an odd number of base atoms for each mound
	!Need to verify the shape of the mounds.  It might be kinda wonky
	if (moundSwitch == 1) then
	
		moundInterval = substrateWidth/moundNumber

		do  i = 1, moundNumber
			!Put mound center at midpoint of moundInterval
			moundCenter = (i-1)*moundInterval + moundInterval/2 - oddModifier
			
			grid(moundCenter - FLOOR(moundWidth/2.0):moundCenter + FLOOR(moundWidth/2.0), numberOfInitialLayers+1)%occupationNumber=1
			do j = 2, moundHeight
				if (MOD(j,2) == 0) then
				
					if(oddModifier == 1) then
						grid(moundCenter-FLOOR(moundWidth/2.0) +(j/2):moundCenter+FLOOR(moundWidth/2.0) -(j/2-1),&
						numberOfInitialLayers+j)%occupationNumber = 1
					else
						grid(moundCenter-FLOOR(moundWidth/2.0) +(j/2-1):moundCenter+FLOOR(moundWidth/2.0) -(j/2),&
						numberOfInitialLayers+j)%occupationNumber = 1
					endif
				else
					grid(moundCenter-FLOOR(moundWidth/2.0) +FLOOR(j/2.0):moundCenter+FLOOR(moundWidth/2.0) -FLOOR(j/2.0),&
					numberOfInitialLayers+j)%occupationNumber = 1
				endif
			enddo
		enddo
		!Set max heigh with mounds
		gridMaxHeight = numberOfInitialLayers + moundHeight
	endif
	
	!Import the initial grid.  Need to modify this to account for even/oddness.  I don't think I'll need to do this
	if (resumeSwitch == 1) then
	
		do i = 1, substrateWidth
			do j = 1, existingRows
				if(initialGrid(i,j) == 1) then
					grid(i,j)%occupationNumber = 1
					if (movieIndexMax > 0)	then
						movieGrid(i,j,:) = 1
					endif
				elseif(initialGrid(i,j) == 0) then
					grid(i,j)%occupationNumber = 0
				else
					print *, 'The grid was not right', i, j
				endif
			enddo
		enddo

		!Set max height with read in data
		gridMaxHeight = existingRows
	endif
		
!	Set the coordinate spacing for the grid
!	In meters
	deltaYGrid = 2.158000463e-10
	deltaXGrid = 2.491844297e-10
	
end subroutine gridInitialize