!New deposition file to replace deposit.f03, momentumDeposit.f03, and trajectoryHelpers.f03.
!Additions will be needed to cover all the functionality of the old files. AKA Movie features
!The steps in the new process are listed below
!We've simplified the deposition process and hopefully it works correctly now.
!Now we find the initial position, and slowly increase the distance the atom travels.
!With each step we determine the four nearest lattice sites, and measure the distance between them and the vapor atom
!Need to account for even/odd rows when determining closest neighbors and distances.
subroutine hexDeposit()

use globalVariables
use indexConversion

real, dimension(2) :: initialLocation, vaporCoords
real, dimension(2) :: siteCoords
real, dimension(2,2) :: currentLocations
integer, dimension(2,11) :: movieCoordinates
integer, dimension(4) :: latticeNodeTest
real, dimension(4,2) :: nearestNodes
real, dimension(4) :: distances
real, parameter :: deltaDistance = 0.1
real :: deltaY, distance, thetaVapor, doubleX, evenModifier
integer :: i ,j, distanceCount

!open (unit = 18, file = "trajectory.txt", status = 'replace')


distance = 0
distanceCount = 0
deltaY = 0.8660254038
j = 1
evenMOdifier = 0
depositTime = 0.0

!Assign initial values
initialLocation(1) = depositionFlux(atomCount,1)
initialLocation(2) = (gridMaxHeight + 2)*deltaY
thetaVapor = REAL(depositionFlux(atomCount,2))

!Update the movieGrid
if (movieIndex <= movieIndexMax) then
	movieCoordinates = movieCoordinateFinder(boundaryConditionChecker(NINT(initialLocation(1))) &
	, NINT(initialLocation(2)))
	movieGrid(movieCoordinates(1,1), movieCoordinates(2,1), movieIndex) = 2
endif

!Start at the initial location and go until deposited
outer: do 
	
	!Save the previous location
	if (j /= 1) then
		currentLocations(2,:) = currentLocations(1,:)
		!write(unit = 18, fmt = *), currentLocations(1,1),currentLocations(1,2)/deltaY, nearestNodes(1,:),&
		! nearestNodes(2,:), nearestNodes(3,:),nearestNodes(4,:)
	endif
	
	!Find the current location
	currentLocations(1,1) = initialLocation(1) -SIN(thetaVapor * pi/180.0)*distance
	currentLocations(1,2) = initialLocation(2) -COS(thetaVapor * pi/180.0)*distance
	doubleX = currentLocations(1,1) *2.0
	
	!Keep the unwrapped coordinates to calculate distance
	nearestNodes(1,1) = FLOOR(doubleX)/2.0
	nearestNodes(2,1) = nearestNodes(1,1)
	nearestNodes(3,1) = CEILING(doubleX)/2.0
	nearestNodes(4,1) = nearestNodes(3,1)
	nearestNodes(1,2) = FLOOR(currentLocations(1,2)/deltaY)
	nearestNodes(2,2) = CEILING(currentLocations(1,2)/deltaY)
	nearestNodes(3,2) = CEILING(currentLocations(1,2)/deltaY)
	nearestNodes(4,2) = FLOOR(currentLocations(1,2)/deltaY)
	
	!Check the location of the atom vs even/odd rows
	!If we are above an even row, the lower atoms will be at half integers while the higher will be at full integers
	!I think this is the weak point in the program, the mods don't identify the correct locations
	if(MOD(NINT(nearestNodes(1,2)), 2) == 0) then
		
		if(MOD(nearestNodes(1,1),1.0) == 0) then
			latticeNodeTest(1) = 0
			latticeNodeTest(2) = 1
			latticeNodeTest(3) = 0
			latticeNodeTest(4) = 1
		elseif(MOD(nearestNodes(4,1),1.0) == 0) then
			latticeNodeTest(1) = 1
			latticeNodeTest(2) = 0
			latticeNodeTest(3) = 1
			latticeNodeTest(4) = 0
		else
			!print*, 'MOD error, checks arent working right 1', MOD(nearestNodes(1,1),1.0), MOD(nearestNodes(4,1),1.0),&
			!nearestNodes(1,1), nearestNodes(4,1),FLOOR(doubleX), CEILING(doubleX), currentLocations(1,1), distance
		endif
	else
		if(MOD(nearestNodes(1,1),1.0) == 0) then
			latticeNodeTest(1) = 1
			latticeNodeTest(2) = 0
			latticeNodeTest(3) = 1
			latticeNodeTest(4) = 0
		elseif(MOD(nearestNodes(4,1),1.0) == 0) then
			latticeNodeTest(1) = 0
			latticeNodeTest(2) = 1
			latticeNodeTest(3) = 0
			latticeNodeTest(4) = 1
		else
			!print*, 'MOD error, checks arent working right 2', MOD(nearestNodes(1,1),1.0), MOD(nearestNodes(4,1),1.0),&
			!nearestNodes(1,1), nearestNodes(4,1), FLOOR(doubleX), CEILING(doubleX), currentLocations(1,1), distance
		endif
	endif
	
	distanceCount = 0
	
	!Find the distances from the real lattice sites
	!Need to account for the atom wrapping around the boundary multiple times! (it seems to be happening on the little grids).
	do i = 1,4
		
		if(MOD(NINT(nearestNodes(i,2)),2) == 0) then
			!Need to account for 0 indices
			!print *, NINT(nearestNodes(i,1)-.5), multiBCC(NINT(nearestNodes(i,1)-.5)) 
			if(grid(multiBCC(NINT(nearestNodes(i,1)-.5)),NINT(nearestNodes(i,2)))%occupationNumber == 1 &
			.and. latticeNodeTest(i) ==1) then
				distances(i) = SQRT((currentLocations(1,1) - nearestNodes(i,1))**2 + (currentLocations(1,2) - nearestNodes(i,2)*deltaY)**2)
				distanceCount = distanceCount + 1
				!print *, 'distance 1', distances(i), i
				evenModifier = 0.5
			else
				distances(i) = 10
			endif
		else
			if(grid(multiBCC(NINT(nearestNodes(i,1))),NINT(nearestNodes(i,2)))%occupationNumber == 1 .and. latticeNodeTest(i) ==1) then
				distances(i) = SQRT((currentLocations(1,1) - nearestNodes(i,1))**2 + (currentLocations(1,2) - nearestNodes(i,2)*deltaY)**2)
				distanceCount = distanceCount + 1
				!print *, 'distance 2', distances(i), i
			else
				distances(i) = 10
			endif
		endif
		
		if(distanceCount > 1) then
			!print *, 'We have multiple qualifying deposition sites, should check out further'
		endif
		
		if(distances(i) < 1.0) then
		
			vaporCoords(1) = currentLocations(1,1)
			vaporCoords(2) = currentLocations(1,2)/deltaY
			siteCoords(1) =  nearestNodes(i,1)
			siteCoords(2) = nearestNodes(i,2)
			
			!print *, distances
			!print *, vaporCoords, siteCoords
			!print *, multiBCC(CEILING(nearestNodes(i,1))), &
			!NINT(nearestNodes(i,2))
			call stickSiteFinder(vaporCoords, siteCoords)
			exit outer
		endif
	enddo
	
	distance = distance + deltaDistance
	!print *, 'Not close enough, distance = ', distance
	j = j+1
enddo outer
			
	!Find the neighboring lattice sites, starting at bottom left and moving clockwise
!	neighborCoords(1,1) = 
!	neighborCoords(1,2) = FLOOR(currentLocations(1,2)/deltaY)
!	neighborCoords(2,1) = boundaryConditionChecker(FLOOR(currentLocations(1,1)))
!	neighborCoords(2,2) = CEILING(currentLocations(1,2)/deltaY)
!	neighborCoords(3,1) = boundaryConditionChecker(CEILING(currentLocations(1,1)))
!	neighborCoords(3,2) = CEILING(currentLocations(1,2)/deltaY)
!	neighborCoords(4,1) = boundaryConditionChecker(CEILING(currentLocations(1,1)))
!	neighborCoords(4,2) = FLOOR(currentLocations(1,2)/deltaY)
	

!	numberOfCloseSites = 0
!
!	!Check to see if we've moved into a new neighborhood.  If so, find the distances to all locations
!	if (neighborCoords == oldNeighborCoords .or. j == 1) then
!		print *, 'Have not moved yet'
!	else
!		do i = 1,4
!			neighborDistances(i) = SQRT((currentLocations(1,1)-nearestNodes(i,1))**2 + (currentLocations(1,2)-neighborCoords(i,2)*deltaY)**2)
!		
!			!Check if there are multiple qualifying close sites
!			if (neighborDistances(i) < 1) then
!				numberOfCloseSites = numberOfCloseSites + 1
!			endif
!		enddo
!	
!		!If there are multiple close sites, send error message
!		if (numberOfCloseSites > 1) then
!			print *, 'More than one close site, reduce deltaDistance and try again', numberOfCloseSites
!		endif
!	
!		!If we don't have too many locations, then call stickSiteFinder and get the heck out
!		do i = 1,4
!			if (neighborDistances(i) < 1) then
!				call stickSiteFinder(currentLocations(1,1),currentLocations(1,2)/deltaY, neighborCoords(i,:))
!				exit outer
!			endif
!		enddo
!	endif
!	close(18)
end subroutine hexDeposit