!New deposition file to replace deposit.f03, momentumDeposit.f03, and trajectoryHelpers.f03.
!Additions will be needed to cover all the functionality of the old files. AKA Movie features
!The steps in the new process are listed below
!1: Determine the coordinates for the point 2x the radius on the line perpendicular to the flight vector. (check)
!2: Find the (occupied) lattice points that fall in the area between the two lines
!3: Find the distance between the occupied points and the initial position.
!4: Find the possible site cloest to the start
!5: Go down to the Y location 1 above the closest site and step by 1/100th of the deltaY until you overlap distances
!6: Determine the final site based on the interseciton location and angle of incidence

subroutine hexDeposit()

use globalVariables
use indexConversion

!Create an array to hold the initial positions.  left in first row, right in second. X&Y in respective columns
!We'll do everything in units where atoms have diameter of 1
real, dimension(2,2) :: initialLocation
real, dimension(2,2) :: currentLocation
real, dimension(2,2) :: unwrappedLocation
integer, dimension(10,2) :: possibleSites
real, dimension(10) :: possibleSitesDistances
integer, dimension(2) :: closestSite
real, dimension(2) :: finalApproach
integer, dimension(2,11) :: movieCoordinates
real :: distance, oddModifier
integer :: i, j, k, xInitial, thetaVapor, yInitial

!Assign initial values
xInitial = depositionFlux(atomCount,1)
yInitial = gridMaxHeight + 5
thetaVapor = depositionFlux(atomCount,2)

!Update the movieGrid
if (movieIndex <= movieIndexMax) then
	movieCoordinates = movieCoordinateFinder(boundaryConditionChecker(xInitial), yInitial)
	movieGrid(movieCoordinates(1,1), movieCoordinates(2,1), movieIndex) = 2
endif

!Find the starting points of the path edges
initialLocation(1,1) = real(xInitial) - COS(depositionFlux(atomCount,2)*pi/90.0)
print *, pi, COS(depositionFlux(atomCount,2)*pi/90.0), depositionFlux(atomCount,2)
initialLocation(1,2) = yInitial*0.707106781 + SIN(depositionFlux(atomCount,2)*pi/90.0)
initialLocation(2,1) = real(xInitial) + COS(depositionFlux(atomCount,2)*pi/90.0)
initialLocation(2,2) = yInitial*0.707106781 - SIN(depositionFlux(atomCount,2)*pi/90.0)

k = 1
!Need to account for the path crossing over the boundary, do this by using the unwrapped coordinates
!Name the loops so we can exit out of the outer one.
!Instead of the current method, lets just go down the central trajectory of the atom a small distance at a time.
!Each time we'll test the four closest sites by using all combinations of CEILING, and FLOOR of X&Y values.
!If any of these sites are within 1, we'll exit the program and determine where to deposit it.
!If there are multiple sites within 1, we should decrease the step size and try again!

print *, 'yInitial', yInitial
outer: do j = yInitial,1,-1
inner:	do i = 1, substrateWidth
	
		!Check what row we're on and adjust i accordingly
		if (mod(j,2) > 0)	then
			oddModifier = 0
		else
			oddModifier = 0.5
		endif
	
		!We should be checking for occupied sites, as these are where the collisions will happen
		if(grid(i,j)%occupationNumber == 1) then
			!Check if the present site is within the path
			!May need to modify boundary condition checker to take reals
			!Need to incorporate oddModifier
			!We shouldn't be using the y-index to assign these values.  We initially set them to off-axis values
			!for a reason.  Giving them this value eliminates this tilt
			currentLocation(1,2) = REAL(j)*0.707106781
			currentLocation(1,1) = boundaryFLoat(initialLocation(1,1) - &
			SIN(depositionFlux(atomCount,2)*pi/90)*(initialLocation(1,2)-j*0.707106781))
			currentLocation(2,2) = REAL(j)*0.707106781
			currentLocation(2,1) = boundaryFloat(initialLocation(2,1) - &
			SIN(depositionFlux(atomCount,2)*pi/90)*(initialLocation(2,2)-j*0.707106781))
			
			!Keep the unwrappedLocation of the two sites
			unwrappedLocation(1,2) = REAL(j)*0.707106781
			unwrappedLocation(1,1) = initialLocation(1,1) - SIN(depositionFlux(atomCount,2)*pi/90)*(initialLocation(1,2)-j*0.707106781)
			unwrappedLocation(2,2) = REAL(j)*0.707106781
			unwrappedLocation(2,1) = initialLocation(2,1) - SIN(depositionFlux(atomCount,2)*pi/90)*(initialLocation(2,2)-j*0.707106781)
			
			print *, 'currentLocation', currentLocation(1,1), currentLocation(1,2)/0.707106781, currentLocation(2,1), &
			currentLocation(2,2)/0.707106781, 'i and j', i, j
			!Make sure that a border hasn't been crossed, which swaps the left and right coordinates
			if (currentLocation(1,1) < currentLocation(2,1)) then
			
				if(real(i) + oddModifier > currentLocation(1,1) .AND. real(i) + oddModifier < currentLocation(2,1)) then
					!Save the coordinates of the 10 closest valid sites
					possibleSites(k,1) = i
					possibleSites(k,2) = j
				
					!Find the distance between the initial location and the site.  Uses unwrapped location
					possibleSitesDistances(k) = SQRT((NINT(unwrappedLocation(1,1))-xInitial)**2 + &
					((yInitial*0.707106781-NINT(unwrappedLocation(1,2))))**2)
					k = k + 1
					print *, 'Added to possibleSites: 1'
					if (k > 10) then
						exit outer
					endif
				endif
				
			!Test the two situations where a border might be crossed but still have a valid site.
			else
				if (real(i) + oddModifier > currentLocation(1,1) .and. real(i) + oddModifier < unwrappedlocation(2,1)) then
					!Save the coordinates of the 10 closest valid sites
					possibleSites(k,1) = i
					possibleSites(k,2) = j
				
					!Find the distance between the initial location and the site.  Uses unwrapped location
					possibleSitesDistances(k) = SQRT((NINT(unwrappedLocation(1,1))-xInitial)**2 + &
					((yInitial*0.707106781-NINT(unwrappedLocation(1,2))))**2)
					k = k + 1
					print *, 'Added to possibleSites: 2'

					if (k > 10) then
						exit outer
					endif
				elseif (real(i) + oddModifier > unwrappedLocation(1,1) .and. real(i) + oddModifier < currentLocation (2,1)) then
					!Save the coordinates of the 10 closest valid sites
					possibleSites(k,1) = i
					possibleSites(k,2) = j
				
					!Find the distance between the initial location and the site.  Uses unwrapped location
					possibleSitesDistances(k) = SQRT((NINT(unwrappedLocation(1,1))-xInitial)**2 + &
					((yInitial*0.707106781-NINT(unwrappedLocation(1,2))))**2)
					k = k + 1
					print *, 'Added to possibleSites: 3'

					if (k > 10) then
						exit outer
					endif
				endif
			endif
		endif
	enddo inner
enddo outer

!Find the closest site.  This returns grid, not deposition, coordinates
closestSite(1) = possibleSites(MINLOC(possibleSitesDistances,1),1)
closestSite(2) = possibleSites(MINLOC(possibleSitesDistances,1),2)

!Move down to the trajectory to 1 spot above the overlapping atom
finalApproach(2) = closestSite(2)*0.707106781 + 1
finalApproach(1) = xInitial- SIN(depositionFlux(atomCount,2)*pi/90)*(yInitial*0.707106781-finalApproach(2))

!Start going down to the atom when its really close.
do i = 1, 500

	distance = SQRT((real(closestSite(1))-finalApproach(1))**2 + (closestSite(2)*0.707106781-finalApproach(2))**2)
	print *, 'distance', distance, 'siteLocation', closestSite(1), closestSite(2)*0.707106781 , 'finalApproach', finalApproach
	if(distance < 1.0) then
		!print *, 'Calling sticksiteFinder'
		call stickSiteFinder
		exit
	else
		!print *, 'Not close enough, distance:', distance
		finalApproach(2) = finalApproach(2) - .005
		finalApproach(1) = xInitial- SIN(depositionFlux(atomCount,2)*pi/90)*(yInitial*0.707106781-finalApproach(2))
	endif
enddo

end subroutine hexDeposit