!Module to calcualte the leafIndex or gridIndex for a given lattice site
!Will allow for easy and independent conversion
!
!Variables
!xIndex, yIndex, leafIndex, substrateWidth
!
!Modules & subroutines
!globalVariables, gridToJump, jumpToGrid, jumpToEnergy (these are two contained in this file, which I like, but need tweaked
!
!Possible issues?
!There could be some conflicts immediately around the halfway point of the leaf nodes, although I doubt there will
!be enough data to cause a collision (that would require a nearly full tree)
!!!THIS NEEDS TO BE MODIFIED TO RETURN THE INDEX VALUE WITHIN THE ENTIRE BINARY TREE
module indexConversion
	use globalVariables
	public :: gridToJump, jumpToGrid, jumpToEnergy, boundaryConditionChecker, movieCoordinateFinder, boundaryFloat, multiBCC
	
	contains
	!Need indices and substrateWidth to calculate
	function gridToJump(xIndexLocal, yIndexLocal) result(leafIndexLocal)
	
		integer, intent(in) :: xIndexLocal, yIndexLocal
		integer :: leafIndexLocal,leafIndexLocal1

		!Let's not worry about keeping the tree balanced, and keep conversions simple, later we could tweak
		!We should return the actual position in the tree, not the position in the leaves
		leafIndexLocal1 = (xIndexLocal + (yIndexLocal -1) * substrateWidth) + firstLeafIndex -1
		leafIndexLocal = (boundaryConditionChecker(xIndexLocal) + (yIndexLocal -1) * substrateWidth) + firstLeafIndex -1
	end function gridToJump
	
	!Need one index and substrateWidth to calculate
	!Returns a row vector of x and y indices
	function jumpToGrid(leafIndexLocal) result(indexesLocal)
	
		integer, intent(in) :: leafIndexLocal
		integer, dimension(1,2) :: indexesLocal
		
		!Ignore the even and oddness
		indexesLocal(1,2) = CEILING((leafIndexLocal-firstLeafIndex +1.0)/substrateWidth)
		indexesLocal(1,1) = CEILING((leafIndexLocal -firstLeafIndex +1.0) - (indexesLocal(1,2) -1)*substrateWidth)
		!!print *, 'leafIndex', leafIndexLocal, 'indexes',indexesLocal, 'jumpToGrid'
	end function jumpToGrid
	
	!Takes the leafNode index and returns the location in the energy array
	!Will need to select a specific jump from the array
	function jumpToEnergy(leafIndexLocal) result(energyIndexLocal)
		integer, intent(in) :: leafIndexLocal
		integer :: energyIndexLocal
		
		energyIndexLocal = (leafIndexLocal +1 - firstLeafIndex)*6 - 6
		!!print *, 'leafIndex', leafIndexLocal, 'energyIndex', energyIndexLocal, 'firstLeafIndex', firstLeafIndex, 'jumpToEnergy'
	end function jumpToEnergy
	
	!Takes in an x-coordinate and checks for boundary conditions.  If needed, loops it around
	function boundaryConditionChecker(xIndexLocal) result(newXIndex)
		integer, intent(in) :: xIndexLocal
		integer :: newXIndex
		
		
		
		if (xIndexLocal > substrateWidth) then
			newXIndex = xIndexLocal -substrateWidth
		elseif(xIndexLocal < 1) then
			newXIndex = xIndexLocal + substrateWidth
		else
			newXIndex = xIndexLocal
		endif
	end function boundaryConditionChecker
	
	!works like boundaryConditionChecker, but allows for multiple loops.  Good during deposition
	function multiBCC(xIndexLocal) result(newXIndex)
		integer, intent(in) :: xIndexLocal
		integer :: newXIndex, wrapDivisor
		real :: wrapCount
		
		wrapCount = xIndexLocal/(real(substrateWidth)+0.01)
		if(wrapCount > 1.0) then
			wrapDivisor = FLOOR(wrapCount)
			!print *, 'Wrapped around!', wrapDivisor
		elseif(wrapCount < 0.0) then
			wrapDivisor = FLOOR(wrapCount)
			!print *, wrapDivisor
		else
			wrapDivisor = 0
		endif
		

		
		newXIndex =xIndexLocal - wrapDivisor*substrateWidth
		!print *, 'newXIndex', newXIndex, 'xIndexLocal', xIndexLocal
		
		if(xIndexLocal == 0) then
			newXIndex = substrateWidth
		endif
	end function multiBCC
	
	!Takes in a floating point value and determines whether we need to wrap around.  We'll draw the wrap line at
	!integer substrate width plus .75 to ensure a continuous grid upon wrapping
	function boundaryFloat(xLocation) result(xLocationNew)
		real, intent(in) :: xLocation
		real :: xLocationNew
		
		!I'm not sure if the substrate width is always the proper quantity to add or subtract.
	
		if(xLocation > substrateWidth + .75) then
			xLocationNew = xLocation - substrateWidth
		elseif(xLocation < .75) then
			xLocationNew = xLocation + substrateWidth
		else
			xLocationNew = xLocation
		endif
	
	end function boundaryFloat
	
	!Returns the called index and its neighbor atoms for easy use in the movie recording scheme
	!Could easily be adapted to be of more general use
	function movieCoordinateFinder(xIndexLocal, yIndexLocal) result(movieCoordinates)
		integer, intent(in) :: xIndexLocal, yIndexLocal
		integer, dimension(2, 11) :: movieCoordinates
		integer :: oddModifier
		
		if (mod(yIndexLocal,2) > 0)	then
			oddModifier = 1
		else
			oddModifier = 0
		endif
!		!print*, 'xIndex', xIndexLocal, 'yIndex', yIndexLocal
		
		movieCoordinates(:,1) = (/boundaryConditionChecker(xIndexLocal), yIndexLocal/)
		movieCoordinates(:,2) = (/boundaryConditionChecker(xIndexLocal -oddModifier), yIndexLocal -1/)
		movieCoordinates(:,3) = (/boundaryConditionChecker(xIndexLocal -oddModifier), yIndexLocal +1/)
		movieCoordinates(:,4) = (/boundaryConditionChecker(xIndexLocal +1 -oddModifier), yIndexLocal -1/)
		movieCoordinates(:,5) = (/boundaryConditionChecker(xIndexLocal +1 -oddModifier), yIndexLocal +1/)
		movieCoordinates(:,6) = (/boundaryConditionChecker(xIndexLocal -1 -oddModifier), yIndexLocal -1/)
		movieCoordinates(:,7) = (/boundaryConditionChecker(xIndexLocal +2 -oddModifier), yIndexLocal -1/)
		movieCoordinates(:,8) = (/boundaryConditionChecker(xIndexLocal -1 -oddModifier), yIndexLocal +1/)
		movieCoordinates(:,9) = (/boundaryConditionChecker(xIndexLocal +2 -oddModifier), yIndexLocal +1/)
		movieCoordinates(:,10)= (/boundaryConditionChecker(xIndexLocal -1), yIndexLocal/)
		movieCoordinates(:,11)= (/boundaryConditionChecker(xIndexLocal +1), yIndexLocal/)
!		!print *, movieCoordinates, 'IndexConversion'
	end function movieCoordinateFinder
		
end module indexConversion