!Reads in input files which include kmc.in, the main control file; iad.in, the IAD file; kmc.txt, the restart file
!The files included in kmc.in are (in order)
!atoms to deposit
!number of initial layers
!deposition rate
!substrate temperature
!substrate width
!assumed density
!movie index maximum
!mound on/off switch
!number of mounds
!mound width
!mound height
!restart on/off switch
!number of existing rows
!loop on/off switch (for rotation)
!loop number (for rotation, will usually be 0 or 8)
!Modules & subroutines called
!globalVariables
subroutine input()

	use globalVariables
	
	!character*80 :: filename
	!character*80 :: str
	integer :: i,j
	
	
	!Open the input files
	open (unit=11,file = "kmc.in")
	!Read in the distribution of inlet files	
	open (unit=13, file = "iad.in")
	!For easy resuming of simulations, read in the kmc.txt file.  This file is just a series of 1's and 0's
	!to signify filled and unfilled sites respectively.
	open (unit=15, file = "kmc.txt")
	
	!Read in control data from kmc.in
	read (unit = 11, fmt =  *), atomsToDeposit
	read (unit = 11, fmt =  *), numberOfInitialLayers
	read (unit = 11, fmt =  *), depositionRate
	read (unit = 11, fmt =  *), substrateTemperature
	read (unit = 11, fmt =  *), substrateWidth
	!Assumed density allows for a larger grid to account for porosity
	read (unit = 11, fmt = *), assumedDensity
	read (unit = 11, fmt = *), movieIndexMax
	!Are there mounds?
	!Mound input.  moundWidth should be odd, while substrateWidth should be 
	!divisible by moundNumber for most ease.
	!Mound height should be equal or smaller than moundWidth
	read (unit = 11, fmt = *), moundSwitch
	read (unit = 11, fmt = *), moundNumber
	read (unit = 11, fmt = *), moundWidth
	read (unit = 11, fmt = *), moundHeight
	read (unit = 11, fmt = *), resumeSwitch
	read (unit = 11, fmt = *), existingRows
	!Read in values that help with looping
	read (unit = 11, fmt = *), loopSwitch
	read (unit = 11, fmt = *), loopNumber
	read (unit = 11, fmt = *), cycleMultiplier
	
	!Allocate memory for deposition parameters
	allocate(loopDepositionRate(loopNumber))
	allocate(loopAtomsToDeposit(loopNumber))
	
	!Read in the listed parameters for looping from the input file.
	do i = 1,loopNumber 
		read(unit = 11, fmt = *), loopDepositionRate(i)
	enddo
	do i = 1,loopNumber
		read(unit = 11, fmt = *), loopAtomsToDeposit(i)
	enddo
	
	!Echo what was read for verification
	print *, 'Atoms to Deposit',  atomsToDeposit
	print *, '# of Initial Layers', numberOfInitialLayers
	print *, 'Deposition Rate', depositionRate
	print *, 'Substrate Temperature', substrateTemperature
	print *, 'Substrate Width', substrateWidth
	print *, 'Assumed Density', assumedDensity
	print *, 'maximum movie Index', movieIndexMax
	print *, 'Mound on/off switch', moundSwitch
	print *, 'number of mounds', moundNumber
	print *, 'Resume on/off switch',resumeSwitch
	print *, 'number of existing rows',existingRows
	print *, 'loop on/off switch', loopSwitch
	print *, 'number of unique loops', loopNumber
	print *, 'How many times to loop', cycleMultiplier
	if (loopNumber /= 0) then
		do i = 1, loopNumber
			!print *, loopDepositionRate(i)
			!print *, loopAtomsToDeposit(i)
		enddo
	endif
	
	close(11)
	
	!Read in IAD data from iad.in and store in array
	do i = -45,45
		read (unit = 13, fmt = *), iAD(i)
		!Print the first and last values to make sure they're zero
	enddo
	
	print *, iAD(-45)
	print *, iAD(45)
	
	close(13)
	
	!Read in kmc.txt if resumeSwitch = 1, Read the input grid into a 1D array, and then translate that into
	!the usual grid format
	!I have been following the convention of (column, row) for arrays in the program, which now seems backwards...
	if (resumeSwitch == 1) then
		
		allocate(initialGrid(substrateWidth, existingRows))
		do i = 1, existingRows
			read(unit =15, fmt = *)(initialGrid(j,existingRows -i +1), j=1,substrateWidth)
			!print *, initialGrid(:, existingRows -i + 1)
		enddo
	endif
	
	close(15)
		
end subroutine input