!Initialize the jump tree for the first time
!Create the properly sized binary tree, and then fill it
!Nodes should be organized in order from left to right and then bottom up (as tie-breaker)
!Need to fill the tree as evenly as possible on right and left sides,
!so the tree should fill up left to right, but alternate which side of the halfway point they fall on
!We use an array to store the binary tree information, as described in the wikipedia "Binary Tree" article
!The root node has index i = 0, left child at 2i+1 and right child at 2i+2, and parent at (i-1)/2
!Minimizing the size of the tree could be quite useful
!
!Variables:
!maxLatticePoints, leafN, n, treeSize, jumpTree(:), firstLeafIndex
!
!Modules & subroutines
!globalVariables
subroutine jumpTreeInitialize()

	use globalVariables
	integer :: n
	!Find the number of points the jumpTree must cover
	maxLatticePoints= substrateWidth*filmHeightMax
	
	n = 1
	!Loop to find leafN, the total number of levels in the tree
	do
		if (2**(n -1) > maxLatticePoints) then
		
			leafN = n
			exit
		else
			n = n +1
		endif
			
	enddo
	
	treeSize = 2**leafN -1
	print *, 'The jumpTree has this many nodes:', treeSize
	
	!Create a 1d list containing the b-tree with root node @ zero
	allocate(jumpTree(0:treeSize -1))

	jumpTree(:) = 0.0
	
	!Determine where the leaf nodes being in the array.  Total - # of leafNodes
	!The first leaf index should be odd, since we're beginning at zero
	firstLeafIndex = 2**(leafN -1) -1
	if (MOD(firstLeafIndex,2) == 0) then
		print *, 'The First leaf index is even, not good)', firstLeafIndex
	endif
	
	print*, 'The first leaf index is', firstLeafIndex
	
	!Initialize the pointer array for jumpEnergies.  Allocate the size of jumpTree*6
	allocate(jumpEnergies(1:2**(leafN -1)*6))
	!Make all of jumpEnergies point to the zero value of probabilities
	jumpEnergies(:) = 20
	
	
	!print *, jumpEnergies
	
end subroutine jumpTreeInitialize