!Subroutine to call when an atom is moved via diffusion, needs to perform several tasks:
!Update the occupation numbers of the lattice sites
!This program runs after a jump has been selected.  It should update both the jumpTree, and the grid
!Update the coordination of the surrounding lattice sites (of both old and new)
!Update the jump tree (leaf nodes and all above)
!We should convert our siteJumpInfo index in this routine, not in it.
!Advance the diffusion time
!
!Variables used:
!latticeIndex, indexRemainder, i, treeIntersection, leafIndex, grid(:,:), indexes(1,1), indexes(1,2), jumpToGrid(:), treeIndexOld
!treeIndexNew, depositTime, timeInterval

subroutine jumpUpdate(leafIndex, energyIndex)

	use globalVariables
	use coordinationHelpers
	use indexConversion

	integer :: indexRemainder, i, j
	integer, intent(in) :: energyIndex,leafIndex
!	real, intent(in out) :: depositTime
	real :: jumpEnergySum
	integer, dimension(1,2) :: indexes
	integer, dimension(2,11) :: movieCoordinatesOld, movieCoordinatesNew
	integer :: oddModifier, oddModifierOld, xTemp, yTemp, energyIndexLoop, leafIndexLoop
	
	jumpEnergySum = 0.0
	
	!Find what type of jump we're performing, this doesn't seem right.
	indexRemainder = energyIndex - jumpToEnergy(leafIndex)
	!Update the occupation numbers, the lattice index will be the ceiling of the leafIndex divided by six
	
	!Update the vacated lattice site
	!Set the previous locations occupation to zero
	indexes = jumpToGrid(leafIndex)
	grid(indexes(1,1),indexes(1,2))%occupationNumber = 0
	movieCoordinatesOld = movieCoordinateFinder(indexes(1,1),indexes(1,2))
	!Set the jumpEnergy of the vacated site to zero
	!print *, 'Vacated Energy', jumpTree(leafIndex), leafIndex
	jumpTree(leafIndex)= 0.0
	!jumpEnergies(jumpToEnergy(leafIndex):jumpToEnergy(leafIndex)+5) = 0.0
	
	!Determine the evenness of the lattice site
	!oddModifier = 1 is odd row
	if (mod(indexes(1,2),2) > 0)	then
		oddModifierOld = 1
	else
		oddModifierOld = 0
	endif
	

	!Calculate the lattice indices of the new point and occupy it!
	!Need to call siteJumpInfo for all affected sites, don't call coordination, as that's done in siteJump
	!Need to account for Schowebel jumps
	!i = (indexes(1,1) -1, indexes(1,2) -1) i + 1 = (indexes(1,1), indexes(1,2) -1), etc
	select case(indexRemainder)
	
	!This is a Schowebel jump left, needs to skip more
	case(0)
	!	print *, 'Jump 1'
		!Find the site jumped into and occupy it
		!xTemp and yTemp are the filled site, while indexes are the vacated site
		xTemp = boundaryConditionChecker(indexes(1,1) -1 -oddModifierOld)
		yTemp = indexes(1,2) -1
		grid(xTemp, yTemp)%occupationNumber = 1
		movieCoordinatesNew = movieCoordinateFinder(xTemp,yTemp)
		!print *, 'Jumped from', leafIndex, 'to',gridToJump(xTemp,yTemp)
		
		if (mod(yTemp,2) >0)	then
			oddModifier = 1
		else
			oddModifier = 0
		endif
		
	!Schowebel jump right down
	case(1)
	!	print *, 'Jump 2'
		xTemp = boundaryConditionChecker(indexes(1,1) +2 -oddModifierOld)
		yTemp = indexes(1,2) -1
		movieCoordinatesNew = movieCoordinateFinder(xTemp,yTemp)
		grid(xTemp, yTemp)%occupationNumber = 1
		!print *, 'Jumped from', leafIndex, 'to',gridToJump(xTemp,yTemp)
		if (mod(yTemp,2) >0)	then
			oddModifier = 1
		else
			oddModifier = 0
		endif
		
	!Jump to the left
	case(2)
		!print *, 'Jump 3'
		xTemp = boundaryConditionChecker(indexes(1,1) -1)
		yTemp = indexes(1,2)
		if(grid(xTemp,yTemp)%occupationNumber ==1) then
			!print *, 'The left site was occupied and I ruined it', jumpEnergies(energyIndex), indexRemainder, energyIndex,&
			!movieIndex
		endif
		if(coordinationCalculation(xTemp,yTemp) == 1) then
			!print*, 'Jumped over the edge! here be the problem', energyIndex, xTemp, yTemp
		endif
		grid(xTemp, yTemp)%occupationNumber = 1
		movieCoordinatesNew = movieCoordinateFinder(xTemp,yTemp)
		!print *, 'Jumped from', leafIndex, 'to',gridToJump(xTemp,yTemp)
		if (mod(yTemp,2) >0)	then
			oddModifier = 1
		else
			oddModifier = 0
		endif
		
	!jump to the right
	case(3)
	!	print *, 'Jump 4'
		xTemp = boundaryConditionChecker(indexes(1,1) +1)
		yTemp= indexes(1,2)
		if(grid(xTemp,yTemp)%occupationNumber ==1) then
			!print *, 'The right site was occupied and I ruined it', jumpEnergies(energyIndex), indexRemainder, energyIndex,&
			!movieIndex
		endif
		if(coordinationCalculation(xTemp,yTemp) == 1) then
			!print*, 'Jumped over the edge! here be the problem', energyIndex, xTemp, yTemp
		endif
		grid(xTemp, yTemp)%occupationNumber = 1
		movieCoordinatesNew = movieCoordinateFinder(xTemp,yTemp)
		!print *, 'Jumped from', leafIndex, 'to',gridToJump(xTemp,yTemp)
		if (mod(yTemp,2) >0)	then
			oddModifier = 1
		else
			oddModifier = 0
		endif
		
		
	!Schowebel jump left up
	case(4)
	!	print *, 'Jump 5'
		xTemp = boundaryConditionChecker(indexes(1,1) -1 -oddModifierOld)
		yTemp = indexes(1,2) +1
		grid(xTemp, yTemp)%occupationNumber = 1
		movieCoordinatesNew = movieCoordinateFinder(xTemp,yTemp)
		!print *, 'Jumped from', leafIndex, 'to',gridToJump(xTemp,yTemp)
		if (mod(yTemp,2) >0)	then
			oddModifier = 1
		else
			oddModifier = 0
		endif
		
	!Schwoebel jump right up
	case(5)
	!	print *, 'Jump 0'
		xTemp = boundaryConditionChecker(indexes(1,1) +2 -oddModifierOld)
		yTemp = indexes(1,2) +1
		grid(xTemp, yTemp)%occupationNumber = 1
		movieCoordinatesNew = movieCoordinateFinder(xTemp,yTemp)
		!print *, 'Jumped from', leafIndex, 'to',gridToJump(xTemp,yTemp)
		if (mod(yTemp,2) >0)	then
			oddModifier = 1
		else
			oddModifier = 0
		endif
		
	end select
!	print *, 'Jumped from ', indexes
!	print *, 'Jumped to ', xTemp, yTemp, coordinationCalculation(xTemp,yTemp)
	!Update the movie grid around the new site, most of the updating is done in the next timestep,
	!as that's when we'll want to display the neighbor sites
!	print *, 'Working with movie'
	if(movieIndex < movieIndexMax)	then
		movieIndex = movieIndex + 1
		movieGrid(movieCoordinatesNew(1,1),movieCoordinatesNew(2,1), movieIndex) = 2
		movieGrid(movieCoordinatesNew(1,1),movieCoordinatesNew(2,1), movieIndex+1:movieIndexMax) = 1

!		print *, 'Further'
		movieGrid(movieCoordinatesOld(1,1),movieCoordinatesOld(2,1), movieIndex) = 6
		movieGrid(movieCoordinatesOld(1,1),movieCoordinatesOld(2,1), movieIndex+1:movieIndexMax) = 0
	endif

	
	!New method to call siteJumpInfo on only nearby atom sites.  Doesn't need to be too percise
	do i = -4, 4
		do j = -4,4
			if (indexes(1,2) + j > numberOfInitialLayers .and. indexes(1,2) + j < filmHeightMax) then
				if (mod(indexes(1,2) +j,2)>0) then
					oddModifier = 1
				else 
					oddModifier = 0
				endif
				leafIndexLoop = gridToJump(boundaryConditionChecker(indexes(1,1) + i), indexes(1,2) +j)
				energyIndexLoop =jumpToEnergy(leafIndexLoop)
				call siteJumpInfo(leafIndexLoop, energyIndexLoop, oddModifier)
			!	print *, 'updating sites', indexes, i, j
			endif
		enddo
	enddo
	
	
end subroutine jumpUpdate