!Determines whether a touching particle should be deposited
!using a momentum-dependent scheme
!It also accounts for the "relaxation" of the atom
!The evenness of a layer matters.
!Odd layers follow the form of the initial atomic layer, while even layers fit in the spaces between.
!The Odd layers will stick out further on the left and even layers will stick out further on the right
!The perodic boundary conditions are then somewhat rough in regards to the real x-component and will need
!to take evenness into account.
!Change the program to use the case construct, instead of If statements, using values from coordinationCalc program
!
!Variables Used
!nextXSpot, realXIndex, nextXIndex, nextYIndex, grid(:,:), deposited, xIndex, yIndex, evenIndex, boundaryConditionModifier
!newAtom, deltaYGrid, deltaXGrid, substrateWidth, oddIndex, coordination, singleNeighborLocation
!
!Subroutines & functions called
!globalVariables
!Need to make sure that call matches the definitino
subroutine momentumDeposit()

	use globalVariables
	use coordinationHelpers
	use indexConversion
	!All of these declared in global variables.  May want to compartmentalize more in the future.
!	integer, intent(in) :: xIndex, yIndex, xVapor, thetaVapor, boundaryConditionModifier, evenIndex, oddIndex, coordination &
!		singleNeighborLocation
!	integer, intent(out) :: deposited
	real :: nextXSpot
	real :: realXIndex
	integer :: nextXIndex, nextYIndex, depositedXIndex, depositedYIndex

	nextXSpot = 0.0
	realXIndex = 0.0
!	!print *, 'Beginning momentumDeposit'
	!If the vapor atom neighbors 2 or more atoms then its stable, otherwise relax it
	if (coordination >= 2) then
!		!print *, 'Two atoms'
		!The next line is wrong, did I forget to set up the grid or something?
		!This line might be ok, but its yIndex is starting out at zero, which is way bad
		if (grid(xIndex, yIndex)%occupationNumber == 1) then
			!print *, 'Error: overwriting existing point 1', xIndex, yIndex, atomCount, movieIndex
		endif
		grid(xIndex, yIndex)%occupationNumber = 1
		deposited = 1
		depositedXIndex = xIndex
		depositedYIndex = yIndex

		!Update the jumpTree and the maximum height.
		call depositionUpdate(depositedXIndex, depositedYIndex)
		if(yIndex > gridMaxHeight) then				
			gridMaxHeight = yIndex
			!print *, 'new Max ', gridMaxHeight 
		endif
	elseif (coordination == 1) then		
	!Check where neighboring atom is and act appropriately
	!This is a simplified version of single neighbor deposition
	!Ignores situations where the neighbor atom is below or beside an atom
	!Only deposits in two possible configurations, the side-by-side situations may need to be accounted for
		singleNeighborLocation = singleNeighborFinder(xIndex, yIndex)
		select case (singleNeighborLocation)
		
			case (1)
				!print *, 'Deposit Case 1'
				if (grid(boundaryConditionChecker(xIndex + evenIndex), yIndex - 1)%occupationNumber == 1) then
					!print *, 'Error: overwriting existing point 2', xIndex, yIndex, atomCount, movieIndex
				endif
				if (coordinationCalculation(boundaryConditionChecker(xIndex + evenIndex), yIndex - 1) < 1) then
					grid(boundaryConditionChecker(xIndex + evenIndex), yIndex - 1)%occupationNumber = 1
					deposited = 1
					depositedXIndex = boundaryConditionChecker(xIndex + evenIndex)
					depositedYIndex = yIndex -1
				endif
			case (2)
				!print *, 'Deposit Case 2'
	!			call output()
				!!print *, 'To right, checking for occupation', atomCount
				nextXSpot= TAN(newAtom%thetaVapor*ACOS(0.0)/90.0) * deltaYGrid + newAtom%xVapor
				nextYIndex = YIndex - 1
				if (evenness > 0) then
					realXIndex = nextXSpot / deltaXGrid
					nextXIndex = NINT(realXIndex) + 1
				else
					realXIndex = newAtom%xVapor / deltaXGrid
					nextXIndex = CEILING(realXIndex)
				endif
				if (grid(boundaryConditionChecker(nextXIndex), nextYIndex)%occupationNumber == 1) then
		!!			grid(xIndex, yIndex)%occupationNumber = 1
		!			deposited = 1
		!			depositedXIndex = xIndex
		!			depositedYIndex = yIndex
					!print *, 'It was occupied, I feel like such an intruder'
				endif
				!!print *, 'It made through'
			case (3:4)
				!print *, 'Deposit Case 3-4'
				!!print *, 'Below, continuing', atomCount
			case (5)				
				!print *, 'Deposit Case 5'
				!!print *, 'To left, checking for occupation', atomCount
				nextXSpot= TAN(newAtom%thetaVapor*ACOS(0.0)/90.0) * deltaYGrid + newAtom%xVapor
				nextYIndex = YIndex - 1
				if (evenness > 0) then
					realXIndex = nextXSpot / deltaXGrid
					nextXIndex = NINT(realXIndex) + 1
				else
					realXIndex = newAtom%xVapor / deltaXGrid
					nextXIndex = CEILING(realXIndex)
				endif
				if (nextXIndex < 1) then
					nextXIndex = substrateWidth - nextXIndex
				elseif (nextXIndex > substrateWidth) then
					nextXIndex = nextXIndex - substrateWidth
				endif
				if (grid(nextXIndex, nextYIndex)%occupationNumber == 1) then
	!				grid(xIndex, yIndex)%occupationNumber = 1
	!				deposited = 1
	!				depositedXIndex = xIndex
	!				depositedYIndex = yIndex
					!print *, 'It was occupied, I feel like such an intruder'
				endif
			case (6)
				!print *, 'Deposit Case 6'
				if(grid(boundaryConditionChecker(xIndex - oddIndex), yIndex - 1)%occupationNumber == 1) then
					!print *, 'Error: overwriting exisiting point 3', xIndex, yIndex, atomCount, movieIndex
				endif
				if (coordinationCalculation(boundaryConditionChecker(xIndex - oddIndex), yIndex - 1) < 1) then
					grid(boundaryConditionChecker(xIndex - oddIndex), yIndex - 1)%occupationNumber = 1
					deposited = 1
					depositedXIndex = boundaryConditionChecker(xIndex - oddIndex)
					depositedYIndex = yIndex -1
				endif
			case default
				!print *, 'Case select error, uh oh', movieIndex, singleNeighborLocation
		end select
		
		!Update the binary tree information
		if (deposited == 1) then
			!!print *, 'Calling depositionUpdate'
			call depositionUpdate(depositedXIndex, depositedYIndex)
		endif
!		!print *, 'got closer'
		if (deposited == 1 .and. depositedYIndex > gridMaxHeight) then
			gridMaxHeight = depositedYIndex
			!!print *, 'new Max ', gridMaxHeight
		endif
!		!print *, 'got even closer'
	else
		!print *, 'Coordination does not match', movieIndex
	endif	
!	!print *, 'Made through !print'
	!Update the movieGrid
	if (movieIndex < movieIndexMax .and. deposited ==1) then
		movieIndex = movieIndex + 1
		movieGrid(depositedXIndex, depositedYIndex, movieIndex:movieIndexMax) = 1
	!	!print *, 'momentumDeposit movieGrid'
	endif
!	!print *, 'It made through whole subroutine'
end subroutine momentumDeposit
		