!Calculates possible diffusion paths, and their energies, for a given lattice site
!Accepts one lattice site and its corresponding index, then returns the values associated with it
!Need to work on Schoewbel barrier, and also how to handle the energies returned
!
!Variables used
!jumpEnergies, leafN, evenness, indexes, grid(:,:), n, 
!modules and subroutines
!globalVariables, coordinationCalculation
subroutine siteJumpInfo(leafIndex,energyIndex, oddModifier)

	use globalVariables
	use indexConversion
	use coordinationHelpers
	!Create a matrix with the possible jump energies the two incides will tell you what direction the jump is in
	!The value at each index will be the energy associated with the jumps, which will tell us the coordination at the new site
	!real, dimension(n+4) :: jumpEnergies
	!The allocation should go into the diffuse routine and be run only once.
!	allocate(jumpEnergies(6))
	!Find the coordination for a given point, will need to rewrite coordination program
!	integer, intent(in) :: indexes(1,1), indexes(1,2)

	!We should accept the jumpTree leaf position as input, as this is the data type we'll work with
	integer, intent(in) :: leafIndex, energyIndex, oddModifier
	!real, dimension(1,6), intent(in, out) :: jumpEnergies
	integer, dimension(1,2) :: indexes
	integer ::leafIndexOld, i
	
	!jumpToGrid returns a 1x2 index of indexes(1,1) and indexes(1,2), need to aply it to them in array form
	indexes = jumpToGrid(leafIndex)
	
	!!print *, leafIndex, energyIndex, oddModifier, coordinationCalculation(indexes(1,1), indexes(1,2)), 'siteJump'
	
	!Check whether the position is occupied and zero out the energy tree for that location
	if(grid(boundaryConditionChecker(indexes(1,1)), indexes(1,2))%occupationNumber /= 1)	then
		!!print *, 'siteJumpInfo was called on a vacant site, exiting!'
		jumpTree(leafIndex) = 0.0
		jumpEnergies(energyIndex:energyIndex+5) = 20
		leafIndexOld = leafIndex
		!Move one rung up the tree
		leafIndexOld = FLOOR((leafIndexOld -1)/2.0)
		!Update the binary tree
		do i = 2, leafN
			jumpTree(leafIndexOld) = jumpTree(2*leafIndexOld + 1) + jumpTree(2*leafIndexOld +2)
!			!print *, 'old index at', i, jumpTree(leafIndexOld)
			leafIndexOld = FLOOR((leafIndexOld -1)/2.0)
		enddo
	!	!print *, 'Zeroed out a vacant site', leafIndex
		return
	endif
	!!print *, 'but still going!', leafIndex
	!Check if the atom is in the stationary inital layer area, if so, leave the subroutine
	if(indexes(1,2) <= numberOfInitialLayers)	then
		!!print *, 'This is in the initial layer region, Im going home', indexes(1,2)
		return
	endif
	
	jumpEnergies(energyIndex:energyIndex+5) = 20
	jumpTree(leafIndex) = 0.0
	
	!!print *, 'What is the case?',coordinationCalculation(boundaryConditionChecker(indexes(1,1)), indexes(1,2))
	select case (coordinationCalculation(boundaryConditionChecker(indexes(1,1)), indexes(1,2)))
	
	!This case can happen during deposition as well, if we look at one of the positions above the deposition
	!site after we've processed the deposition one
	case (1)
		!print *, 'Only 1 neighbor atom, atom deleted', grid(indexes(1,1),indexes(1,2))%occupationNumber,&
		!indexes(1,1),indexes(1,2)
	!	print *, grid(indexes(1,1) -1,indexes(1,2))%occupationNumber, grid(indexes(1,1)+1,indexes(1,2))%occupationNumber
	!	print *, grid(indexes(1,1)-1:indexes(1,1)+1, indexes(1,2)-1)%occupationNumber
	!	grid(indexes(1,1),indexes(1,2)%occupationNumber = 0
		return
	!Coordination of 2 has 5 possible moves 2->2, 2->3, 2->4, 2->5, 2->3S
	!Case 2 is really the only situation where multiple moves are possible.  Atom can go left or right.
	!Otherwise, direction is limited by surrounding atoms.
	case (2)
!		!print *, 'Normal coordination', indexes(1,:)
		!Two on bottom
		if(grid(boundaryConditionChecker(indexes(1,1) - oddModifier), indexes(1,2) -1)%occupationNumber == 1&
		.and. grid(boundaryConditionChecker(indexes(1,1) + 1 - oddModifier),indexes(1,2) -1)%occupationNumber ==1) then
			!!print *, 'siteJump3-1'
			!!print *,'Coordinationcalc', coordinationCalculation(boundaryConditionChecker(indexes(1,1) - 1), indexes(1,2))
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) - 1), indexes(1,2)) == 3) then
				!!print *, 'siteJump3-1-1', energyIndex +2
				jumpEnergies(energyIndex+2) = 5
			elseif( coordinationCalculation(boundaryConditionChecker(indexes(1,1) - 1), indexes(1,2)) == 4) then
				!!print *, 'siteJump3-1-2'
				jumpEnergies(energyIndex+2) = 4
			elseif( coordinationCalculation(boundaryConditionChecker(indexes(1,1) -1), indexes(1,2)) == 5) then
				!!print *, 'siteJump3-1-3'
				jumpEnergies(energyIndex+2) = 2
			!Schwoebel jumps, and prevent regular jumps
			elseif( coordinationCalculation(boundaryConditionChecker(indexes(1,1) -1), indexes(1,2)) == 2) then
				!!print *, 'siteJump3-1-4'
				jumpEnergies(energyIndex) = 7
				jumpEnergies(energyIndex+2) = 20
			!Edge atom with no support
			else
				!print *, '2-1 Coordination diffusion error, no data above' ,&
				!coordinationCalculation(boundaryConditionChecker(indexes(1,1) -1), indexes(1,2)), indexes(1,1)-1, indexes(1,2),&
				!movieIndex
			endif
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) + 1), indexes(1,2)) == 3) then
				!!print *, 'siteJump3-1-5'
				jumpEnergies(energyIndex+3) = 5
			elseif( coordinationCalculation(boundaryConditionChecker(indexes(1,1) + 1), indexes(1,2)) == 4) then
				!!print *, 'siteJump3-1-6'
				jumpEnergies(energyIndex+3) = 4
			elseif( coordinationCalculation(boundaryConditionChecker(indexes(1,1) +1), indexes(1,2)) == 5) then
				!!print *, 'siteJump3-1-7'
				jumpEnergies(energyIndex+3) = 2
			elseif( coordinationCalculation(boundaryConditionChecker(indexes(1,1) +1), indexes(1,2)) == 2) then
				!!print *, 'siteJump3-1-8'
				jumpEnergies(energyIndex+1) = 7
			else
				!print *, '2-2 Coordination diffusion error, no data above' ,&
				!coordinationCalculation(boundaryConditionChecker(indexes(1,1) +1), indexes(1,2)), indexes(1,1)+1, indexes(1,2)
			endif
		!Two on top
		elseif(grid(boundaryConditionChecker(indexes(1,1) -oddModifier), indexes(1,2) +1)%occupationNumber == 1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) + 1 -oddModifier), indexes(1,2) + 1)%occupationNumber == 1) then
			!!print *, 'siteJump3-2'
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) - 1), indexes(1,2)) == 3) then
				!!print *, 'siteJump3-1-9'
				jumpEnergies(energyIndex+2) = 5
			elseif( coordinationCalculation(boundaryConditionChecker(indexes(1,1) - 1), indexes(1,2)) == 4) then
				!!print *, 'siteJump3-1-10'
				jumpEnergies(energyIndex+2) = 4
			elseif( coordinationCalculation(boundaryConditionChecker(indexes(1,1) -1), indexes(1,2)) == 5) then
				!!print *, 'siteJump3-1-11'
				jumpEnergies(energyIndex+2) = 2
			elseif( coordinationCalculation(boundaryConditionChecker(indexes(1,1) -1), indexes(1,2)) == 2) then
				!!print *, 'siteJump3-1-12'
				jumpEnergies(energyIndex+4) = 7
			else
				!print *, '2-3 Coordination diffusion error, no data below' , jumpEnergies(energyIndex:energyIndex+5)
			endif
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) +1), indexes(1,2)) == 3) then
				!!print *, 'siteJump3-1-13'
				jumpEnergies(energyIndex+3) = 5
			elseif( coordinationCalculation(boundaryConditionChecker(indexes(1,1) + 1), indexes(1,2)) == 4) then
				!!print *, 'siteJump3-1-14'
				jumpEnergies(energyIndex+3) = 4
			elseif( coordinationCalculation(boundaryConditionChecker(indexes(1,1) +1), indexes(1,2)) == 5) then
				!!print *, 'siteJump3-1-15'
				jumpEnergies(energyIndex+3) = 2
			elseif( coordinationCalculation(boundaryConditionChecker(indexes(1,1) +1), indexes(1,2)) == 2) then
				!!print *, 'siteJump3-1-16'
				jumpEnergies(energyIndex+5) = 7
			else
				!print *, '2-4 Coordination diffusion error, no data below' , jumpEnergies(energyIndex:energyIndex+5)
			endif
		!Two on left, only valued when the next location has coordination of 5
		elseif(grid(boundaryConditionChecker(indexes(1,1) -oddModifier), indexes(1,2) -1)%occupationNumber ==1 .and. &
		grid(boundaryConditionChecker(indexes(1,1)-oddModifier),indexes(1,2)+1)%occupationNumber ==1) then
			!!print *, 'siteJump3-3'
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) -1), indexes(1,2)) == 6) then
				!!print *, '2-5-1'
				jumpEnergies(energyIndex+2) = 1
			else
				!print *, '2-5 coordination Jump error left', jumpEnergies(energyIndex:energyIndex+5)
			endif
		!Two on Right, only valued when next location has coordination of 5
		elseif(grid(boundaryConditionChecker(indexes(1,1) + 1 -oddModifier), indexes(1,2) -1)%occupationNumber == 1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) + 1 -oddModifier), indexes(1,2) + 1)%occupationNumber ==1) then
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) + 1), indexes(1,2)) == 6) then
				!!print *,'2-5-2'
				jumpEnergies(energyIndex+3) = 1
			else
				!print *, '2-5-1 coordination jump error right', jumpEnergies(energyIndex:energyIndex+5)
			endif
		else
		!	!print*, '2-6 Coordination diffusion error, configuration not in database', jumpEnergies(energyIndex:energyIndex+5),&
!			movieIndex, indexes(1,:),grid(boundaryConditionChecker(indexes(1,1) -oddModifier), indexes(1,2) -1)%occupationNumber,&
!			grid(boundaryConditionChecker(indexes(1,1)-oddModifier),indexes(1,2)+1)%occupationNumber,&
!			grid(boundaryConditionChecker(indexes(1,1) + 1 -oddModifier), indexes(1,2) -1)%occupationNumber,&
!			grid(boundaryConditionChecker(indexes(1,1) + 1 -oddModifier), indexes(1,2) + 1)%occupationNumber,&
!			grid(boundaryConditionChecker(indexes(1,1)-1), indexes(1,2))%occupationNumber, &
!			grid(boundaryConditionChecker(indexes(1,1)+1), indexes(1,2))%occupationNumber, &
!			coordinationCalculation(indexes(1,1),indexes(1,2))
			return
		endif
		
	!Coordination 3 has 5 possible moves 3->2, 3->3, 3->4, 3->5, 3->2S
	case (3)
		!!print *, 'siteJump4'
		!Two below, one next to and left
		if(grid(boundaryConditionChecker(indexes(1,1) - 1), indexes(1,2))%occupationNumber == 1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) -oddModifier), indexes(1,2) -1)%occupationNumber == 1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) + 1 -oddModifier), indexes(1,2) - 1)%occupationNumber ==1) then
			!!print*, 'siteJump4-1'
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) + 1), indexes(1,2)) == 3) then
				jumpEnergies(energyIndex+3) = 12
			elseif(coordinationCalculation(boundaryConditionChecker(indexes(1,1) + 1), indexes(1,2)) == 4) then
				jumpEnergies(energyIndex+3) = 11
			elseif(coordinationCalculation(boundaryConditionChecker(indexes(1,1) + 1), indexes(1,2)) == 5) then
				jumpEnergies(energyIndex+3) = 9
			elseif(coordinationCalculation(boundaryConditionChecker(indexes(1,1) + 1), indexes(1,2)) == 6) then
				jumpEnergies(energyIndex+3) = 3
			endif
			!Schwoebel jumps, the indexing is a little off
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) -1 -oddModifier), indexes(1,2) + 1) == 2 &
			.and. grid(boundaryConditionChecker(indexes(1,1) -1 -oddModifier), indexes(1,2) + 1)%occupationNumber == 0) then
				jumpEnergies(energyIndex+4) = 15
			endif
		!Two below, one next to and right
		elseif(grid(boundaryConditionChecker(indexes(1,1) +1),indexes(1,2))%occupationNumber == 1 .and. &
		grid (boundaryConditionChecker(indexes(1,1) -oddModifier),indexes(1,2)-1)%occupationNumber ==1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) +1 -oddModifier), indexes(1,2) -1)%occupationNumber ==1) then
			!!print*, 'siteJump4-2'
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) - 1), indexes(1,2)) == 3) then
				jumpEnergies(energyIndex+2) = 12
			elseif(coordinationCalculation(boundaryConditionChecker(indexes(1,1) - 1), indexes(1,2)) == 4) then
				jumpEnergies(energyIndex+2) = 11
			elseif(coordinationCalculation(boundaryConditionChecker(indexes(1,1) - 1), indexes(1,2)) == 5) then
				jumpEnergies(energyIndex+2) = 9
			elseif(coordinationCalculation(boundaryConditionChecker(indexes(1,1) - 1), indexes(1,2)) == 6) then
				jumpEnergies(energyIndex+2) = 3
			endif
			!Schwoebel jumps, the indexing is a little off
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) + 2 - oddModifier), indexes(1,2) + 1) == 2 &
			.and. grid(boundaryConditionChecker(indexes(1,1) + 2 - oddModifier), indexes(1,2) + 1)%occupationNumber == 0) then
				jumpEnergies(energyIndex+5) = 15
			endif
		!Two above, one next to and left
		elseif(grid(boundaryConditionChecker(indexes(1,1) - 1), indexes(1,2))%occupationNumber == 1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) -oddModifier), indexes(1,2) +1)%occupationNumber == 1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) + 1 -oddModifier), indexes(1,2) +1)%occupationNumber ==1) then
			!!print*, 'siteJump4-3'
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) + 1), indexes(1,2)) == 3) then
				jumpEnergies(energyIndex+3) = 12
			elseif(coordinationCalculation(boundaryConditionChecker(indexes(1,1) + 1), indexes(1,2)) == 4) then
				jumpEnergies(energyIndex+3) = 11
			elseif(coordinationCalculation(boundaryConditionChecker(indexes(1,1) + 1), indexes(1,2)) == 5) then
				jumpEnergies(energyIndex+3) = 9
			elseif(coordinationCalculation(boundaryConditionChecker(indexes(1,1) + 1), indexes(1,2)) == 6) then
				jumpEnergies(energyIndex+3) = 3
			endif
			!Schwoebel jumps, the indexing is a little off
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) -1 -oddModifier), indexes(1,2) - 1) == 2 &
			.and. grid(boundaryConditionChecker(indexes(1,1)-1 -oddModifier), indexes(1,2) -1)%occupationNumber == 0) then
				jumpEnergies(energyIndex) = 15
			endif
		!Two above, one next to and right
		elseif(grid(boundaryConditionChecker(indexes(1,1) +1),indexes(1,2))%occupationNumber == 1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) -oddModifier), indexes(1,2)+1)%occupationNumber ==1 & 
		.and. grid(boundaryConditionChecker(indexes(1,1) + 1 -oddModifier), indexes(1,2) +1)%occupationNumber ==1) then
			!!print*, 'siteJump4-4'
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) - 1), indexes(1,2)) == 3) then
				jumpEnergies(energyIndex+2) = 12
			elseif(coordinationCalculation(boundaryConditionChecker(indexes(1,1) - 1), indexes(1,2)) == 4) then
				jumpEnergies(energyIndex+2) = 11
			elseif(coordinationCalculation(boundaryConditionChecker(indexes(1,1) - 1), indexes(1,2)) == 5) then
				jumpEnergies(energyIndex+2) = 9
			elseif(coordinationCalculation(boundaryConditionChecker(indexes(1,1) - 1), indexes(1,2)) == 6) then
				jumpEnergies(energyIndex+2) = 3
			endif
			!Schwoebel jumps, the indexing is a little off
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) + 2 -oddModifier), indexes(1,2) - 1) == 2 &
			.and. grid(boundaryConditionChecker(indexes(1,1)+2 - oddModifier), indexes(1,2) - 1)%occupationNumber == 0) then
				jumpEnergies(energyIndex+1) = 15
			endif
		!Two below, one above and left
		elseif(grid(boundaryConditionChecker(indexes(1,1) -oddModifier), indexes(1,2) -1)%occupationNumber == 1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) -oddModifier),indexes(1,2) + 1)%occupationNumber == 1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) + 1 - oddModifier), indexes(1,2) -1)%occupationNumber == 1) then
			!!print*, 'siteJump4-5'
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) -1), indexes(1,2)) ==6) then
				jumpEnergies(energyIndex+2) = 3
			endif
		!Two above, one below and left
		elseif(grid(boundaryConditionChecker(indexes(1,1) -oddModifier), indexes(1,2) -1)%occupationNumber == 1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) -oddModifier),indexes(1,2) + 1)%occupationNumber == 1 &
		.and. grid(boundaryConditionChecker(indexes(1,1) + 1 -oddModifier), indexes(1,2) +1)%occupationNumber == 1) then
			!!print*, 'siteJump4-6'
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) -1), indexes(1,2)) ==6) then
				jumpEnergies(energyIndex+2) = 3
			endif
		!Two below, one above and right
		elseif(grid(boundaryConditionChecker(indexes(1,1) -oddModifier), indexes(1,2) -1)%occupationNumber == 1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) +1 -oddModifier),indexes(1,2) + 1)%occupationNumber == 1 &
		.and. grid(boundaryConditionChecker(indexes(1,1) + 1 -oddModifier), indexes(1,2) -1)%occupationNumber == 1) then
			!!print*, 'siteJump4-7'
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) +1), indexes(1,2)) ==6) then
				jumpEnergies(energyIndex+3) = 3
			endif
		!Two above, one above and right
		elseif(grid(boundaryConditionChecker(indexes(1,1) + 1 -oddModifier), indexes(1,2) -1)%occupationNumber == 1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) -oddModifier),indexes(1,2) + 1)%occupationNumber == 1 &
		.and. grid(boundaryConditionChecker(indexes(1,1) + 1 -oddModifier), indexes(1,2) +1)%occupationNumber == 1) then
			!!print*, 'siteJump4-8'
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) +1), indexes(1,2)) ==6) then
				jumpEnergies(energyIndex+3) = 3
			endif
		else
			!!print *, '3 coordination diffusion error, configuration not in database'
		endif
	
	!Coordination of 4 has 4 possible moves 4->2, 4->3, 4->4, 4->5
	case (4)
		!!print *, 'siteJump5'
		!Two Below, one left, and above left
		if(grid(boundaryConditionChecker(indexes(1,1) - oddModifier), indexes(1,2) -1)%occupationNumber == 1 .and. &
		grid (boundaryConditionChecker(indexes(1,1) + 1 - oddModifier), indexes(1,2) -1)%occupationNumber == 1 &
		.and. grid(boundaryConditionChecker(indexes(1,1)- 1), indexes(1,2))%occupationNumber == 1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) - oddModifier), indexes(1,2) + 1)%occupationNumber == 1) then
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) + 1),indexes(1,2)) == 3) then
				jumpEnergies(energyIndex+3) = 17
			elseif(coordinationCalculation(boundaryConditionChecker(indexes(1,1) + 1), indexes(1,2)) == 5) then
				jumpEnergies(energyIndex+3) = 10
			elseif(coordinationCalculation(boundaryConditionChecker(indexes(1,1) + 1), indexes(1,2)) == 4) then
				jumpEnergies(energyIndex+3) = 19
			endif
		!Two below, one right, and above right
		elseif(grid(boundaryConditionChecker(indexes(1,1) - oddModifier), indexes(1,2) -1)%occupationNumber == 1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) + 1 -oddModifier), indexes(1,2) -1)%occupationNumber == 1 &
		.and. grid(boundaryConditionChecker(indexes(1,1) +1), indexes(1,2))%occupationNumber == 1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) +1 -oddModifier), indexes(1,2) + 1)%occupationNumber == 1) then
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) - 1),indexes(1,2)) == 3) then
				jumpEnergies(energyIndex+2) = 17
			elseif(coordinationCalculation(boundaryConditionChecker(indexes(1,1) - 1), indexes(1,2)) == 5) then
				jumpEnergies(energyIndex+2) = 10
			elseif(coordinationCalculation(boundaryConditionChecker(indexes(1,1) - 1), indexes(1,2)) == 4) then
				jumpEnergies(energyIndex+2) = 19
			endif
		!Two below, one right, and above left
		elseif(grid(boundaryConditionChecker(indexes(1,1) - oddModifier), indexes(1,2) -1)%occupationNumber ==1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) +1 -oddModifier), indexes(1,2) -1)%occupationNumber ==1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) +1), indexes(1,2))%occupationNumber ==1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) -oddModifier), indexes(1,2)+1)%occupationNumber ==1) then
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) -1), indexes(1,2)) == 5) then
				jumpEnergies(energyIndex+2) = 6
			endif
		!Two below, one left, and above right
		elseif(grid(boundaryConditionChecker(indexes(1,1) - oddModifier), indexes(1,2) -1)%occupationNumber ==1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) +1 -oddModifier), indexes(1,2) -1)%occupationNumber ==1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) -1), indexes(1,2))%occupationNumber ==1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) +1 -oddModifier), indexes(1,2)+1)%occupationNumber ==1) then
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) -1), indexes(1,2)) == 5) then
				jumpEnergies(energyIndex+3) = 6
			endif
		!Two above, one left, and below left
		elseif(grid(boundaryConditionChecker(indexes(1,1) - oddModifier), indexes(1,2) +1)%occupationNumber == 1 .and. &
		grid (boundaryConditionChecker(indexes(1,1) + 1 -oddModifier), indexes(1,2) +1)%occupationNumber == 1 &
		.and. grid(boundaryConditionChecker(indexes(1,1)-1), indexes(1,2))%occupationNumber == 1 .and. & 
		grid(boundaryConditionChecker(indexes(1,1)-oddModifier), indexes(1,2) - 1)%occupationNumber == 1) then
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) + 1),indexes(1,2)) == 3) then
				jumpEnergies(energyIndex+3) = 17
			elseif(coordinationCalculation(boundaryConditionChecker(indexes(1,1) + 1), indexes(1,2)) == 5) then
				jumpEnergies(energyIndex+3) = 10
			elseif(coordinationCalculation(boundaryConditionChecker(indexes(1,1) + 1), indexes(1,2)) == 4) then
				jumpEnergies(energyIndex+3) = 19
			endif
		!Two above, one right and below right
		elseif(grid(boundaryConditionChecker(indexes(1,1) - oddModifier), indexes(1,2) +1)%occupationNumber == 1 .and. &
		grid (boundaryConditionChecker(indexes(1,1) + 1 -oddModifier), indexes(1,2) +1)%occupationNumber == 1 &
		.and. grid(boundaryConditionChecker(indexes(1,1)+1), indexes(1,2) )%occupationNumber == 1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) +1 -oddModifier), indexes(1,2) - 1)%occupationNumber == 1) then
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) - 1),indexes(1,2)) == 3) then
				jumpEnergies(energyIndex+2) = 17
			elseif(coordinationCalculation(boundaryConditionChecker(indexes(1,1) - 1), indexes(1,2)) == 5) then
				jumpEnergies(energyIndex+2) = 10
			elseif(coordinationCalculation(boundaryConditionChecker(indexes(1,1) - 1), indexes(1,2)) == 4) then
				jumpEnergies(energyIndex+2) = 19
			endif
		!Two below, one right, and above left
		elseif(grid(boundaryConditionChecker(indexes(1,1) - oddModifier), indexes(1,2) +1)%occupationNumber ==1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) +1 -oddModifier), indexes(1,2) +1)%occupationNumber ==1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) +1), indexes(1,2))%occupationNumber ==1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) -oddModifier), indexes(1,2)-1)%occupationNumber ==1) then
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) -1), indexes(1,2)) == 5) then
				jumpEnergies(energyIndex+2) = 6
			endif
		!Two below, one left, and above right
		elseif(grid(boundaryConditionChecker(indexes(1,1) - oddModifier), indexes(1,2) +1)%occupationNumber ==1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) +1 -oddModifier), indexes(1,2) +1)%occupationNumber ==1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) -1), indexes(1,2))%occupationNumber ==1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) +1 -oddModifier), indexes(1,2)-1)%occupationNumber ==1) then
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) -1), indexes(1,2)) == 5) then
				jumpEnergies(energyIndex+3) = 6
			endif
		!Two below, one left, and one right
		elseif(grid(boundaryConditionChecker(indexes(1,1) - oddModifier), indexes(1,2) -1)%occupationNumber ==1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) +1 -oddModifier), indexes(1,2) -1)%occupationNumber ==1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) -1), indexes(1,2))%occupationNumber ==1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) +1), indexes(1,2))%occupationNumber ==1) then
				jumpEnergies(energyIndex:energyIndex+5) = 20
		!Two above, one left, and one right
		elseif(grid(boundaryConditionChecker(indexes(1,1) - oddModifier), indexes(1,2) +1)%occupationNumber ==1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) +1 -oddModifier), indexes(1,2) +1)%occupationNumber ==1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) -1), indexes(1,2))%occupationNumber ==1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) +1), indexes(1,2))%occupationNumber ==1) then
				jumpEnergies(energyIndex:energyIndex+5) = 20
		else
	!		!print *, '4 coordination diffusion error, configuration not in database', jumpEnergies(energyindex:energyIndex+5)
		!	coordinationCalculation(boundaryConditionChecker(indexes(1,1)),indexes(1,2)), indexes(1,1),indexes(1,2), movieIndex
		endif

	!Coordination of 5 has 5 possible moves 5->2, 5->3, 5->4, 5->5, 5->5V
	case (5)
		!!print *, 'siteJump6'
		!Two below and above, and one left
		if(grid(boundaryConditionChecker(indexes(1,1) -oddModifier), indexes(1,2) -1)%occupationNumber == 1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) +1 -oddModifier), indexes(1,2) - 1)%occupationNumber == 1 &
		.and. grid(boundaryConditionChecker(indexes(1,1) -1), indexes(1,2))%occupationNumber == 1 .and. &
		grid(boundaryConditionChecker(indexes(1,1)-oddModifier), indexes(1,2)+1)%occupationNumber == 1 &
		.and. grid(boundaryConditionChecker(indexes(1,1) +1 -oddModifier), indexes(1,2)+1)%occupationNumber == 1) then
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) + 1), indexes(1,2)) == 6) then
				!Check for bulk vacancy diffusion
				!I don't think even/oddness will modify this, as the layers are similar type
				if(grid(boundaryConditionChecker(indexes(1,1) + 1), indexes(1,2) + 2)%occupationNumber== 1 &
				.and. grid(boundaryConditionChecker(indexes(1,1) + 1), indexes(1,2)-2)%occupationNumber ==1) then
					jumpEnergies(energyIndex+3) =18
				else
					jumpEnergies(energyIndex+3) = 8
				endif
			elseif(coordinationCalculation(boundaryConditionChecker(indexes(1,1) + 1), indexes(1,2)) == 3) then
				jumpEnergies(energyIndex+3) = 14
			elseif(coordinationCalculation(boundaryConditionChecker(indexes(1,1) + 1), indexes(1,2)) == 4) then
				jumpEnergies(energyIndex+3) = 16
			elseif(coordinationCalculation(boundaryConditionChecker(indexes(1,1) + 1), indexes(1,2)) == 5) then
				jumpEnergies(energyIndex+3) = 13
			endif
		!Two below and above, and one right
		elseif(grid(boundaryConditionChecker(indexes(1,1) -oddModifier), indexes(1,2) -1)%occupationNumber == 1 .and. &
		grid(boundaryConditionChecker(indexes(1,1) +1 -oddModifier), indexes(1,2) - 1)%occupationNumber == 1 &
		.and. grid(boundaryConditionChecker(indexes(1,1) +1), indexes(1,2))%occupationNumber == 1 .and. &
		grid(boundaryConditionChecker(indexes(1,1)-oddModifier), indexes(1,2)+1)%occupationNumber == 1 &
		.and. grid(boundaryConditionChecker(indexes(1,1) +1 -oddModifier), indexes(1,2)+1)%occupationNumber == 1) then
			if(coordinationCalculation(boundaryConditionChecker(indexes(1,1) - 1), indexes(1,2)) == 6) then
				!Check for bulk vacancy diffusion
				!I don't think even/oddness will modify this, as the layers are similar type
				if(grid(boundaryConditionChecker(indexes(1,1) - 1), indexes(1,2) + 2)%occupationNumber== 1 &
				.and. grid(boundaryConditionChecker(indexes(1,1) - 1), indexes(1,2)-2)%occupationNumber ==1) then
					jumpEnergies(energyIndex+2) =18
				else
					jumpEnergies(energyIndex+2) = 8
				endif
			elseif(coordinationCalculation(boundaryConditionChecker(indexes(1,1) - 1), indexes(1,2)) == 3) then
				jumpEnergies(energyIndex+2) = 14
			elseif(coordinationCalculation(boundaryConditionChecker(indexes(1,1) - 1), indexes(1,2)) == 4)	then
				jumpEnergies(energyIndex+2) = 16
			elseif(coordinationCalculation(boundaryConditionChecker(indexes(1,1) - 1), indexes(1,2)) == 5) then
				jumpEnergies(energyIndex+2) = 13
			endif
		else
			!!print *, '5 coordination diffusion error, configuration not in database', jumpEnergies(energyIndex:energyIndex+5)
		endif
	!The atom is surrounded
	case (6)
		!!print *, 'siteJump7'
		!!print *, 'Atom is immobile, this should not be selected'
		jumpEnergies(energyIndex:energyIndex+5) = 20
	!This case could happen during deposition, depending on the order of reading the positions	
	case default
		!!print *, 'siteJump8'
		if(grid(indexes(1,1),indexes(1,2))%occupationNumber == 1) then
			!print *, 'Incorrect coordination number during diffusion',&
			!coordinationCalculation(boundaryConditionChecker(indexes(1,1)), indexes(1,2)) &
			!, indexes(1,:), leafIndex, oddModifier
		endif
		!Exit this iteration of the subroutine
		return
	end select
	
	!Update the energy sum
	jumpTree(leafIndex) = 0.0
	do i = 0,5
		jumpTree(leafIndex) = jumpTree(leafIndex) + probabilities(jumpEnergies(energyIndex + i))
	enddo
	!!print *, 'New site energy', jumpTree(leafIndex)
	leafIndexOld = leafIndex
	!Move one rung up the tree
	leafIndexOld = FLOOR((leafIndexOld -1)/2.0)
	!Update the binary tree
	do i = 2, leafN
		jumpTree(leafIndexOld) = jumpTree(2*leafIndexOld + 1) + jumpTree(2*leafIndexOld +2)
	!	print *, jumpTree(leafIndexOld)
		leafIndexOld = FLOOR((leafIndexOld -1)/2.0)
	enddo
	
	!if (jumpTree(leafIndex) > 1.0)	then
		!!print *, 'Bad energies', jumpEnergies(energyIndex:energyIndex+5), coordinationCalculation(&
		!boundaryConditionChecker(indexes(1,1) - 1), indexes(1,2))
	!endif
	!!print *, 'siteJump10'
end subroutine siteJumpInfo