!Creates a random sequence of vapor atoms from an inputted IAD.
!Random number creation can vary from compiler to compiler (check for cluster)
!
!Variables
!randomNum, i,j, iADSum, iADNormSum, depositionFlux(:,:), atomsToDeposit, iAD(:), iADNormalize(:)
!Modules & subroutines
!globalVariables, random_seed, random_number
subroutine vaporInitialize()

	use globalVariables
	use indexConversion
	use ifport
	
	!IAD = Incident Angle Distribution, real angle value is iAD*2
	!Measured from substrate normal
	real :: randomNum
	integer :: i, j
	integer, dimension(8) :: timeValues
	real :: iADSum, angleProb
	
	
	call date_and_time(VALUES=timeValues)
	call seed(timeValues(8))

	!Create nx2 array, one column with the initial x position and another with angle (theta)
	allocate(depositionFlux(atomsToDeposit,2))
	!call random_seed() !Seeds random generator, some compilers need different method

	
	!Read in IAD from file
	iADSum = 0.0
	angleProb = 0.0
	
	!Sum IAD and perform normalization
	do i = -45, 44
		iADSum = iADSum + iAD(i)
	end do
	
	!iADNormalized is the sum of probabilities between 0 and 1
	do i = -45, 44
		if (i == -45) then	
			iADNormalized(i) = iAD(i)/iADSum
		else
			iADNormalized(i) = iAD(i)/iADSum + iADNormalized(i-1)
		endif
	end do
	
	
	!Create the deposition array
	do i = 1 , atomsToDeposit
		
		!Assign the inlet location in real coordinates
		!This random generation doesn't quite line up to the grid used in deposition, as it creates atoms with an
		!x-minimum of 0, instead of 1 on the grid, but this can be accounted for by checking the boundary conditions
		!upon generation
		randomNum = rand()
		depositionFlux(i,1) = boundaryFloat(randomNum * (substrateWidth))
		!print *, depositionFlux(i,1)
		!Choose a random angle
		randomNum = rand()
		angleProb = randomNum
		
		!Assign the angle value, use the random number between 0 and 1 to deteremine angle
		do j = -90, 90, 2
			if (angleProb <= iADNormalized(j/2)) then
				depositionFlux(i,2) = j
				exit
			endif
		enddo
		!print *, 'depositionArray', depositionFlux(i,:)
	enddo
	
end subroutine vaporInitialize