%Program to adjust the input files for all the orientations of substrate
%rotation. Only does one cell at a time but could be combined with
%inputAdjust.m to do entire DSMC simulations. Also adjusts the number of
%atoms deposited at each orientation assuming a constant rotation rate.
function[cellFlux, flux] = rotateAdjust(DSMCFile1,DSMCFile2,DSMCFile3,DSMCFile4,DSMCFile5,DSMCFile6, DSMCFile7, DSMCFile8, gridRegionMins,gridRegionMaxs,maxFlux,KMCFile, rotateAdjust)

close all;

%Read in the surface fluxes at each orientation. Our surface processing
%bash script puts all the regions in the correct order
surfaceData(:,1) = surfaceReader(DSMCFile1,gridRegionMins, gridRegionMaxs);
surfaceData(:,2) = surfaceReader(DSMCFile2,gridRegionMins, gridRegionMaxs);
surfaceData(:,3) = surfaceReader(DSMCFile3,gridRegionMins, gridRegionMaxs);
surfaceData(:,4) = surfaceReader(DSMCFile4,gridRegionMins, gridRegionMaxs);
surfaceData(:,5) = surfaceReader(DSMCFile5,gridRegionMins, gridRegionMaxs);
surfaceData(:,6) = surfaceReader(DSMCFile6,gridRegionMins, gridRegionMaxs);
surfaceData(:,7) = surfaceReader(DSMCFile7,gridRegionMins, gridRegionMaxs);
surfaceData(:,8) = surfaceReader(DSMCFile8,gridRegionMins, gridRegionMaxs);

%Determine how many surface cells are involved.
if abs(gridRegionMins - gridRegionMaxs) == 0
    loopSize = 1;
else
    loopSize = abs(gridRegionMins - gridRegionMaxs)+1;
end

%Normalize the data by the overall and individual cell max max
 for i = 1:loopSize
     cellNorm(i,:) = surfaceData(i,:)/max(surfaceData(i,:));
end

cellFlux = cellNorm(:,:)*maxFlux;
maxVector = max(surfaceData(:,:));
surfaceMax = max(maxVector);
fluxNorm = surfaceData(:,:)/surfaceMax;

cellNumber = round(9000000/800*cellNorm(:,:));
for i = 1:loopSize
    cellFactor(i) = sum(cellNumber(i,:))/90000;
    cellNumber(i,:) = round(cellNumber(i,:)/cellFactor(i));
    sum(cellNumber(i,:));
end
%Multiply norm data by the maxFlux
flux = fluxNorm(:,:)*maxFlux;
fluxNumber =round(9000000/800.0*fluxNorm(:,:));

for i = 1:loopSize
    fluxFactor(i) = sum(fluxNumber(i,:))/90000;
    fluxNumber(i,:) = round(fluxNumber(i,:)/fluxFactor(i));
    sum(fluxNumber(i,:));
end

%This is for the rotated deposition, force the 0 and 315 orientations to
%take a larger share of the total deposition
if(rotateAdjust == 1)
    for i = 1:loopSize
        share = .9*9e4;
        sum0315 = fluxNumber(i,1)+fluxNumber(i,8);
        sumOther = sum(fluxNumber(i,2:7));
        newfluxNumber(i,1) = fluxNumber(i,1)/sum0315 * share;
        newfluxNumber(i,8) = fluxNumber(i,8)/sum0315 * share;
        newfluxNumber(i,2:7) = fluxNumber(i,2:7)/sumOther * (9e4-share);
    end
end

%Open source KMC file
file = fopen(KMCFile);
newfluxNumber = fluxNumber;

KMCParams = textscan(file,'%f');
fclose(file);

j = gridRegionMins;
for i = 1:loopSize

    KMCParams{1}(1) = 11250;
    KMCParams{1}(3) = flux(i,1);
    KMCParams{1}(6) = 0.2;
    KMCParams{1}(17:24) = flux(i,1:8);
    KMCParams{1}(25:32) = newfluxNumber(i,1:8);
    KMCParamsReg = KMCParams{1}(:);
    cd(num2str(j));
    file2 = fopen('kmc.in','w+');
    fprintf(file2,'%e\n', KMCParamsReg);
    fclose(file2);
    cd ../;
    
%     KMCParams{1}(1) = 11250;
%     KMCParams{1}(3) = cellFlux(i,1);
%     KMCParams{1}(17:24) = cellFlux(i,1:8);
%     KMCParams{1}(25:32) = cellNumber(i,1:8);
%     KMCParamsReg = KMCParams{1}(:);
%     cd([num2str(j), '-cell']);
%     file3 = fopen('kmc.in','w+');
%     fprintf(file3,'%e\n', KMCParamsReg);
%     fclose(file3);
%     cd ../;
     j = j+1;
end
end 